@@ -13,26 +13,27 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import itertools
+
+from oslo_config import cfg
 import six
 import sqlalchemy
+from sqlalchemy.sql import true
 
 from keystone import catalog
 from keystone.catalog import core
 from keystone.common import sql
-from keystone.common.sql import migration_helpers
-from keystone import config
 from keystone import exception
-from keystone.openstack.common.db.sqlalchemy import migration
 
 
-CONF = config.CONF
+CONF = cfg.CONF
 
 
 class Region(sql.ModelBase, sql.DictBase):
     __tablename__ = 'region'
     attributes = ['id', 'description', 'parent_region_id']
-    id = sql.Column(sql.String(64), primary_key=True)
-    description = sql.Column(sql.String(255))
+    id = sql.Column(sql.String(255), primary_key=True)
+    description = sql.Column(sql.String(255), nullable=False)
     # NOTE(jaypipes): Right now, using an adjacency list model for
     #                 storing the hierarchy of regions is fine, since
     #                 the API does not support any kind of querying for
@@ -42,7 +43,7 @@ class Region(sql.ModelBase, sql.DictBase):
     #                 would be possible to add in columns to this model for
     #                 "left" and "right" and provide support for a nested set
     #                 model.
-    parent_region_id = sql.Column(sql.String(64), nullable=True)
+    parent_region_id = sql.Column(sql.String(255), nullable=True)
 
     # TODO(jaypipes): I think it's absolutely stupid that every single model
     #                 is required to have an "extra" column because of the
@@ -51,6 +52,7 @@ class Region(sql.ModelBase, sql.DictBase):
     #                 bad. Remove all of this extra JSON blob stuff.
     #                 See: https://bugs.launchpad.net/keystone/+bug/1265071
     extra = sql.Column(sql.JsonBlob())
+    endpoints = sqlalchemy.orm.relationship("Endpoint", backref="region")
 
 
 class Service(sql.ModelBase, sql.DictBase):
@@ -59,38 +61,38 @@ class Service(sql.ModelBase, sql.DictBase):
     id = sql.Column(sql.String(64), primary_key=True)
     type = sql.Column(sql.String(255))
     enabled = sql.Column(sql.Boolean, nullable=False, default=True,
-                         server_default='1')
+                         server_default=sqlalchemy.sql.expression.true())
     extra = sql.Column(sql.JsonBlob())
     endpoints = sqlalchemy.orm.relationship("Endpoint", backref="service")
 
 
 class Endpoint(sql.ModelBase, sql.DictBase):
     __tablename__ = 'endpoint'
-    attributes = ['id', 'interface', 'region', 'service_id', 'url',
+    attributes = ['id', 'interface', 'region_id', 'service_id', 'url',
                   'legacy_endpoint_id', 'enabled']
     id = sql.Column(sql.String(64), primary_key=True)
     legacy_endpoint_id = sql.Column(sql.String(64))
     interface = sql.Column(sql.String(8), nullable=False)
-    region = sql.Column(sql.String(255))
+    region_id = sql.Column(sql.String(255),
+                           sql.ForeignKey('region.id',
+                                          ondelete='RESTRICT'),
+                           nullable=True,
+                           default=None)
     service_id = sql.Column(sql.String(64),
                             sql.ForeignKey('service.id'),
                             nullable=False)
     url = sql.Column(sql.Text(), nullable=False)
     enabled = sql.Column(sql.Boolean, nullable=False, default=True,
-                         server_default='1')
+                         server_default=sqlalchemy.sql.expression.true())
     extra = sql.Column(sql.JsonBlob())
 
 
 class Catalog(catalog.Driver):
-    def db_sync(self, version=None):
-        migration.db_sync(
-            sql.get_engine(), migration_helpers.find_migrate_repo(),
-            version=version)
-
     # Regions
-    def list_regions(self):
+    def list_regions(self, hints):
         session = sql.get_session()
-        regions = session.query(Region).all()
+        regions = session.query(Region)
+        regions = sql.filter_limit_query(Region, regions, hints)
         return [s.to_dict() for s in list(regions)]
 
     def _get_region(self, session, region_id):
@@ -99,7 +101,7 @@ class Catalog(catalog.Driver):
             raise exception.RegionNotFound(region_id=region_id)
         return ref
 
-    def _delete_child_regions(self, session, region_id):
+    def _delete_child_regions(self, session, region_id, root_region_id):
         """Delete all child regions.
 
         Recursively delete any region that has the supplied region
@@ -107,7 +109,10 @@ class Catalog(catalog.Driver):
         """
         children = session.query(Region).filter_by(parent_region_id=region_id)
         for child in children:
-            self._delete_child_regions(session, child.id)
+            if child.id == root_region_id:
+                # Hit a circular region hierarchy
+                return
+            self._delete_child_regions(session, child.id, root_region_id)
             session.delete(child)
 
     def _check_parent_region(self, session, region_ref):
@@ -122,6 +127,20 @@ class Catalog(catalog.Driver):
             # which is the behavior we want.
             self._get_region(session, parent_region_id)
 
+    def _has_endpoints(self, session, region, root_region):
+        if region.endpoints is not None and len(region.endpoints) > 0:
+            return True
+
+        q = session.query(Region)
+        q = q.filter_by(parent_region_id=region.id)
+        for child in q.all():
+            if child.id == root_region.id:
+                # Hit a circular region hierarchy
+                return False
+            if self._has_endpoints(session, child, root_region):
+                return True
+        return False
+
     def get_region(self, region_id):
         session = sql.get_session()
         return self._get_region(session, region_id).to_dict()
@@ -130,8 +149,9 @@ class Catalog(catalog.Driver):
         session = sql.get_session()
         with session.begin():
             ref = self._get_region(session, region_id)
-            self._delete_child_regions(session, region_id)
-            session.query(Region).filter_by(id=region_id).delete()
+            if self._has_endpoints(session, ref, ref):
+                raise exception.RegionDeletionError(region_id=region_id)
+            self._delete_child_regions(session, region_id, region_id)
             session.delete(ref)
 
     @sql.handle_conflicts(conflict_type='region')
@@ -150,6 +170,7 @@ class Catalog(catalog.Driver):
             ref = self._get_region(session, region_id)
             old_dict = ref.to_dict()
             old_dict.update(region_ref)
+            self._ensure_no_circle_in_hierarchical_regions(old_dict)
             new_region = Region.from_dict(old_dict)
             for attr in Region.attributes:
                 if attr != 'id':
@@ -204,8 +225,8 @@ class Catalog(catalog.Driver):
     # Endpoints
     def create_endpoint(self, endpoint_id, endpoint_ref):
         session = sql.get_session()
-        self.get_service(endpoint_ref['service_id'])
         new_endpoint = Endpoint.from_dict(endpoint_ref)
+
         with session.begin():
             session.add(new_endpoint)
         return new_endpoint.to_dict()
@@ -235,6 +256,7 @@ class Catalog(catalog.Driver):
 
     def update_endpoint(self, endpoint_id, endpoint_ref):
         session = sql.get_session()
+
         with session.begin():
             ref = self._get_endpoint(session, endpoint_id)
             old_dict = ref.to_dict()
@@ -246,15 +268,35 @@ class Catalog(catalog.Driver):
             ref.extra = new_endpoint.extra
         return ref.to_dict()
 
-    def get_catalog(self, user_id, tenant_id, metadata=None):
-        d = dict(six.iteritems(CONF))
-        d.update({'tenant_id': tenant_id,
-                  'user_id': user_id})
+    def get_catalog(self, user_id, tenant_id):
+        """Retrieve and format the V2 service catalog.
+
+        :param user_id: The id of the user who has been authenticated for
+            creating service catalog.
+        :param tenant_id: The id of the project. 'tenant_id' will be None
+            in the case this being called to create a catalog to go in a
+            domain scoped token. In this case, any endpoint that requires
+            a tenant_id as part of their URL will be skipped (as would a whole
+            service if, as a consequence, it has no valid endpoints).
+
+        :returns: A nested dict representing the service catalog or an
+                  empty dict.
+
+        """
+        substitutions = dict(
+            itertools.chain(six.iteritems(CONF),
+                            six.iteritems(CONF.eventlet_server)))
+        substitutions.update({'user_id': user_id})
+        silent_keyerror_failures = []
+        if tenant_id:
+            substitutions.update({'tenant_id': tenant_id})
+        else:
+            silent_keyerror_failures = ['tenant_id']
 
         session = sql.get_session()
         endpoints = (session.query(Endpoint).
                      options(sql.joinedload(Endpoint.service)).
-                     filter(Endpoint.enabled == True).all())  # flake8: noqa
+                     filter(Endpoint.enabled == true()).all())
 
         catalog = {}
 
@@ -262,15 +304,21 @@ class Catalog(catalog.Driver):
             if not endpoint.service['enabled']:
                 continue
             try:
-                url = core.format_url(endpoint['url'], d)
+                formatted_url = core.format_url(
+                    endpoint['url'], substitutions,
+                    silent_keyerror_failures=silent_keyerror_failures)
+                if formatted_url is not None:
+                    url = formatted_url
+                else:
+                    continue
             except exception.MalformedEndpoint:
                 continue  # this failure is already logged in format_url()
 
-            region = endpoint['region']
+            region = endpoint['region_id']
             service_type = endpoint.service['type']
             default_service = {
                 'id': endpoint['id'],
-                'name': endpoint.service['name'],
+                'name': endpoint.service.extra.get('name', ''),
                 'publicURL': ''
             }
             catalog.setdefault(region, {})
@@ -280,13 +328,31 @@ class Catalog(catalog.Driver):
 
         return catalog
 
-    def get_v3_catalog(self, user_id, tenant_id, metadata=None):
-        d = dict(six.iteritems(CONF))
-        d.update({'tenant_id': tenant_id,
-                  'user_id': user_id})
+    def get_v3_catalog(self, user_id, tenant_id):
+        """Retrieve and format the current V3 service catalog.
+
+        :param user_id: The id of the user who has been authenticated for
+            creating service catalog.
+        :param tenant_id: The id of the project. 'tenant_id' will be None in
+            the case this being called to create a catalog to go in a domain
+            scoped token. In this case, any endpoint that requires a
+            tenant_id as part of their URL will be skipped.
+
+        :returns: A list representing the service catalog or an empty list
+
+        """
+        d = dict(
+            itertools.chain(six.iteritems(CONF),
+                            six.iteritems(CONF.eventlet_server)))
+        d.update({'user_id': user_id})
+        silent_keyerror_failures = []
+        if tenant_id:
+            d.update({'tenant_id': tenant_id})
+        else:
+            silent_keyerror_failures = ['tenant_id']
 
         session = sql.get_session()
-        services = (session.query(Service).filter(Service.enabled == True).
+        services = (session.query(Service).filter(Service.enabled == true()).
                     options(sql.joinedload(Service.endpoints)).
                     all())
 
@@ -295,19 +361,26 @@ class Catalog(catalog.Driver):
                 del endpoint['service_id']
                 del endpoint['legacy_endpoint_id']
                 del endpoint['enabled']
+                endpoint['region'] = endpoint['region_id']
                 try:
-                    endpoint['url'] = core.format_url(endpoint['url'], d)
+                    formatted_url = core.format_url(
+                        endpoint['url'], d,
+                        silent_keyerror_failures=silent_keyerror_failures)
+                    if formatted_url:
+                        endpoint['url'] = formatted_url
+                    else:
+                        continue
                 except exception.MalformedEndpoint:
                     continue  # this failure is already logged in format_url()
 
                 yield endpoint
 
+        # TODO(davechen): If there is service with no endpoints, we should skip
+        # the service instead of keeping it in the catalog, see bug #1436704.
         def make_v3_service(svc):
             eps = list(make_v3_endpoints(svc.endpoints))
             service = {'endpoints': eps, 'id': svc.id, 'type': svc.type}
-            name = svc.extra.get('name')
-            if name:
-                service['name'] = name
+            service['name'] = svc.extra.get('name', '')
             return service
 
         return [make_v3_service(svc) for svc in services]
