@@ -17,6 +17,8 @@
 
 import abc
 
+from oslo_config import cfg
+from oslo_log import log
 import six
 
 from keystone.common import cache
@@ -24,43 +26,52 @@ from keystone.common import dependency
 from keystone.common import driver_hints
 from keystone.common import manager
 from keystone.common import utils
-from keystone import config
 from keystone import exception
 from keystone.i18n import _
 from keystone.i18n import _LE
 from keystone import notifications
-from keystone.openstack.common import log
 
 
-CONF = config.CONF
+CONF = cfg.CONF
 LOG = log.getLogger(__name__)
-SHOULD_CACHE = cache.should_cache_fn('catalog')
-
-EXPIRATION_TIME = lambda: CONF.catalog.cache_time
+MEMOIZE = cache.get_memoization_decorator(section='catalog')
 
 
-def format_url(url, substitutions):
+def format_url(url, substitutions, silent_keyerror_failures=None):
     """Formats a user-defined URL with the given substitutions.
 
     :param string url: the URL to be formatted
     :param dict substitutions: the dictionary used for substitution
+    :param list silent_keyerror_failures: keys for which we should be silent
+        if there is a KeyError exception on substitution attempt
     :returns: a formatted URL
 
     """
+
+    WHITELISTED_PROPERTIES = [
+        'tenant_id', 'user_id', 'public_bind_host', 'admin_bind_host',
+        'compute_host', 'compute_port', 'admin_port', 'public_port',
+        'public_endpoint', 'admin_endpoint', ]
+
     substitutions = utils.WhiteListedItemFilter(
-        CONF.catalog.endpoint_substitution_whitelist,
+        WHITELISTED_PROPERTIES,
         substitutions)
+    allow_keyerror = silent_keyerror_failures or []
     try:
         result = url.replace('$(', '%(') % substitutions
     except AttributeError:
-        LOG.error(_('Malformed endpoint - %(url)r is not a string'),
+        LOG.error(_LE('Malformed endpoint - %(url)r is not a string'),
                   {"url": url})
         raise exception.MalformedEndpoint(endpoint=url)
     except KeyError as e:
-        LOG.error(_LE("Malformed endpoint %(url)s - unknown key %(keyerror)s"),
-                  {"url": url,
-                   "keyerror": e})
-        raise exception.MalformedEndpoint(endpoint=url)
+        if not e.args or e.args[0] not in allow_keyerror:
+            LOG.error(_LE("Malformed endpoint %(url)s - unknown key "
+                          "%(keyerror)s"),
+                      {"url": url,
+                       "keyerror": e})
+            raise exception.MalformedEndpoint(endpoint=url)
+        else:
+            result = None
     except TypeError as e:
         LOG.error(_LE("Malformed endpoint '%(url)s'. The following type error "
                       "occurred during string substitution: %(typeerror)s"),
@@ -89,8 +100,7 @@ class Manager(manager.Manager):
     def __init__(self):
         super(Manager, self).__init__(CONF.catalog.driver)
 
-    @notifications.created(_REGION, public=False, result_id_arg_attr='id')
-    def create_region(self, region_ref):
+    def create_region(self, region_ref, initiator=None):
         # Check duplicate ID
         try:
             self.get_region(region_ref['id'])
@@ -100,32 +110,43 @@ class Manager(manager.Manager):
             msg = _('Duplicate ID, %s.') % region_ref['id']
             raise exception.Conflict(type='region', details=msg)
 
-        # NOTE(lbragstad): The description column of the region database
-        # can not be null. So if the user doesn't pass in a description then
-        # set it to an empty string.
-        region_ref.setdefault('description', '')
+        # NOTE(lbragstad,dstanek): The description column of the region
+        # database cannot be null. So if the user doesn't pass in a
+        # description or passes in a null description then set it to an
+        # empty string.
+        if region_ref.get('description') is None:
+            region_ref['description'] = ''
         try:
-            return self.driver.create_region(region_ref)
+            ret = self.driver.create_region(region_ref)
         except exception.NotFound:
             parent_region_id = region_ref.get('parent_region_id')
             raise exception.RegionNotFound(region_id=parent_region_id)
 
-    @cache.on_arguments(should_cache_fn=SHOULD_CACHE,
-                        expiration_time=EXPIRATION_TIME)
+        notifications.Audit.created(self._REGION, ret['id'], initiator)
+        return ret
+
+    @MEMOIZE
     def get_region(self, region_id):
         try:
             return self.driver.get_region(region_id)
         except exception.NotFound:
             raise exception.RegionNotFound(region_id=region_id)
 
-    @notifications.updated(_REGION, public=False)
-    def update_region(self, region_id, region_ref):
-        return self.driver.update_region(region_id, region_ref)
+    def update_region(self, region_id, region_ref, initiator=None):
+        # NOTE(lbragstad,dstanek): The description column of the region
+        # database cannot be null. So if the user passes in a null
+        # description set it to an empty string.
+        if 'description' in region_ref and region_ref['description'] is None:
+            region_ref['description'] = ''
+        ref = self.driver.update_region(region_id, region_ref)
+        notifications.Audit.updated(self._REGION, region_id, initiator)
+        self.get_region.invalidate(self, region_id)
+        return ref
 
-    @notifications.deleted(_REGION, public=False)
-    def delete_region(self, region_id):
+    def delete_region(self, region_id, initiator=None):
         try:
             ret = self.driver.delete_region(region_id)
+            notifications.Audit.deleted(self._REGION, region_id, initiator)
             self.get_region.invalidate(self, region_id)
             return ret
         except exception.NotFound:
@@ -135,28 +156,31 @@ class Manager(manager.Manager):
     def list_regions(self, hints=None):
         return self.driver.list_regions(hints or driver_hints.Hints())
 
-    @notifications.created(_SERVICE, public=False)
-    def create_service(self, service_id, service_ref):
+    def create_service(self, service_id, service_ref, initiator=None):
         service_ref.setdefault('enabled', True)
-        return self.driver.create_service(service_id, service_ref)
+        service_ref.setdefault('name', '')
+        ref = self.driver.create_service(service_id, service_ref)
+        notifications.Audit.created(self._SERVICE, service_id, initiator)
+        return ref
 
-    @cache.on_arguments(should_cache_fn=SHOULD_CACHE,
-                        expiration_time=EXPIRATION_TIME)
+    @MEMOIZE
     def get_service(self, service_id):
         try:
             return self.driver.get_service(service_id)
         except exception.NotFound:
             raise exception.ServiceNotFound(service_id=service_id)
 
-    @notifications.updated(_SERVICE, public=False)
-    def update_service(self, service_id, service_ref):
-        return self.driver.update_service(service_id, service_ref)
+    def update_service(self, service_id, service_ref, initiator=None):
+        ref = self.driver.update_service(service_id, service_ref)
+        notifications.Audit.updated(self._SERVICE, service_id, initiator)
+        self.get_service.invalidate(self, service_id)
+        return ref
 
-    @notifications.deleted(_SERVICE, public=False)
-    def delete_service(self, service_id):
+    def delete_service(self, service_id, initiator=None):
         try:
             endpoints = self.list_endpoints()
             ret = self.driver.delete_service(service_id)
+            notifications.Audit.deleted(self._SERVICE, service_id, initiator)
             self.get_service.invalidate(self, service_id)
             for endpoint in endpoints:
                 if endpoint['service_id'] == service_id:
@@ -169,32 +193,48 @@ class Manager(manager.Manager):
     def list_services(self, hints=None):
         return self.driver.list_services(hints or driver_hints.Hints())
 
-    @notifications.created(_ENDPOINT, public=False)
-    def create_endpoint(self, endpoint_id, endpoint_ref):
+    def _assert_region_exists(self, region_id):
         try:
-            return self.driver.create_endpoint(endpoint_id, endpoint_ref)
+            if region_id is not None:
+                self.get_region(region_id)
         except exception.RegionNotFound:
             raise exception.ValidationError(attribute='endpoint region_id',
                                             target='region table')
-        except exception.NotFound:
-            service_id = endpoint_ref.get('service_id')
-            raise exception.ServiceNotFound(service_id=service_id)
 
-    @notifications.updated(_ENDPOINT, public=False)
-    def update_endpoint(self, endpoint_id, endpoint_ref):
-        return self.driver.update_endpoint(endpoint_id, endpoint_ref)
+    def _assert_service_exists(self, service_id):
+        try:
+            if service_id is not None:
+                self.get_service(service_id)
+        except exception.ServiceNotFound:
+            raise exception.ValidationError(attribute='endpoint service_id',
+                                            target='service table')
 
-    @notifications.deleted(_ENDPOINT, public=False)
-    def delete_endpoint(self, endpoint_id):
+    def create_endpoint(self, endpoint_id, endpoint_ref, initiator=None):
+        self._assert_region_exists(endpoint_ref.get('region_id'))
+        self._assert_service_exists(endpoint_ref['service_id'])
+        ref = self.driver.create_endpoint(endpoint_id, endpoint_ref)
+
+        notifications.Audit.created(self._ENDPOINT, endpoint_id, initiator)
+        return ref
+
+    def update_endpoint(self, endpoint_id, endpoint_ref, initiator=None):
+        self._assert_region_exists(endpoint_ref.get('region_id'))
+        self._assert_service_exists(endpoint_ref.get('service_id'))
+        ref = self.driver.update_endpoint(endpoint_id, endpoint_ref)
+        notifications.Audit.updated(self._ENDPOINT, endpoint_id, initiator)
+        self.get_endpoint.invalidate(self, endpoint_id)
+        return ref
+
+    def delete_endpoint(self, endpoint_id, initiator=None):
         try:
             ret = self.driver.delete_endpoint(endpoint_id)
+            notifications.Audit.deleted(self._ENDPOINT, endpoint_id, initiator)
             self.get_endpoint.invalidate(self, endpoint_id)
             return ret
         except exception.NotFound:
             raise exception.EndpointNotFound(endpoint_id=endpoint_id)
 
-    @cache.on_arguments(should_cache_fn=SHOULD_CACHE,
-                        expiration_time=EXPIRATION_TIME)
+    @MEMOIZE
     def get_endpoint(self, endpoint_id):
         try:
             return self.driver.get_endpoint(endpoint_id)
@@ -205,9 +245,9 @@ class Manager(manager.Manager):
     def list_endpoints(self, hints=None):
         return self.driver.list_endpoints(hints or driver_hints.Hints())
 
-    def get_catalog(self, user_id, tenant_id, metadata=None):
+    def get_catalog(self, user_id, tenant_id):
         try:
-            return self.driver.get_catalog(user_id, tenant_id, metadata)
+            return self.driver.get_catalog(user_id, tenant_id)
         except exception.NotFound:
             raise exception.NotFound('Catalog not found for user and tenant')
 
@@ -219,6 +259,22 @@ class Driver(object):
     def _get_list_limit(self):
         return CONF.catalog.list_limit or CONF.list_limit
 
+    def _ensure_no_circle_in_hierarchical_regions(self, region_ref):
+        if region_ref.get('parent_region_id') is None:
+            return
+
+        root_region_id = region_ref['id']
+        parent_region_id = region_ref['parent_region_id']
+
+        while parent_region_id:
+            # NOTE(wanghong): check before getting parent region can ensure no
+            # self circle
+            if parent_region_id == root_region_id:
+                raise exception.CircularRegionHierarchyError(
+                    parent_region_id=parent_region_id)
+            parent_region = self.get_region(parent_region_id)
+            parent_region_id = parent_region.get('parent_region_id')
+
     @abc.abstractmethod
     def create_region(self, region_ref):
         """Creates a new region.
@@ -376,7 +432,7 @@ class Driver(object):
         raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
-    def get_catalog(self, user_id, tenant_id, metadata=None):
+    def get_catalog(self, user_id, tenant_id):
         """Retrieve and format the current service catalog.
 
         Example::
@@ -400,7 +456,7 @@ class Driver(object):
         """
         raise exception.NotImplemented()  # pragma: no cover
 
-    def get_v3_catalog(self, user_id, tenant_id, metadata=None):
+    def get_v3_catalog(self, user_id, tenant_id):
         """Retrieve and format the current V3 service catalog.
 
         The default implementation builds the V3 catalog from the V2 catalog.
@@ -430,7 +486,7 @@ class Driver(object):
         :raises: keystone.exception.NotFound
 
         """
-        v2_catalog = self.get_catalog(user_id, tenant_id, metadata=metadata)
+        v2_catalog = self.get_catalog(user_id, tenant_id)
         v3_catalog = []
 
         for region_name, region in six.iteritems(v2_catalog):
