@@ -13,14 +13,17 @@
 # under the License.
 """Wrapper for keystone.common.config that configures itself on import."""
 
+import logging
 import os
 
+from oslo_config import cfg
+from oslo_log import log
+
 from keystone.common import config
 from keystone import exception
-from keystone.openstack.common import log
 
 
-CONF = config.CONF
+CONF = cfg.CONF
 
 setup_authentication = config.setup_authentication
 configure = config.configure
@@ -40,20 +43,18 @@ def set_default_for_default_log_levels():
     extra_log_level_defaults = [
         'dogpile=INFO',
         'routes=INFO',
+        'keystone.common._memcache_pool=INFO',
     ]
 
-    def find_default_log_levels_opt():
-        for opt in log.log_opts:
-            if opt.dest == 'default_log_levels':
-                return opt
-
-    opt = find_default_log_levels_opt()
-    opt.default.extend(extra_log_level_defaults)
+    log.register_options(CONF)
+    CONF.set_default('default_log_levels',
+                     CONF.default_log_levels + extra_log_level_defaults)
 
 
 def setup_logging():
     """Sets up logging for the keystone package."""
-    log.setup('keystone')
+    log.setup(CONF, 'keystone')
+    logging.captureWarnings(True)
 
 
 def find_paste_config():
