@@ -12,20 +12,20 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from oslo_config import cfg
 import six
 
 from keystone.catalog.backends import sql
 from keystone.catalog import core as catalog_core
 from keystone.common import dependency
-from keystone import config
 from keystone import exception
 
-CONF = config.CONF
+CONF = cfg.CONF
 
 
 @dependency.requires('endpoint_filter_api')
 class EndpointFilterCatalog(sql.Catalog):
-    def get_v3_catalog(self, user_id, project_id, metadata=None):
+    def get_v3_catalog(self, user_id, project_id):
         substitutions = dict(six.iteritems(CONF))
         substitutions.update({'tenant_id': project_id, 'user_id': user_id})
 
@@ -36,11 +36,11 @@ class EndpointFilterCatalog(sql.Catalog):
         if (not refs and
                 CONF.endpoint_filter.return_all_endpoints_if_no_filter):
             return super(EndpointFilterCatalog, self).get_v3_catalog(
-                user_id, project_id, metadata=metadata)
+                user_id, project_id)
 
         for entry in refs:
             try:
-                endpoint = self.get_endpoint(entry.endpoint_id)
+                endpoint = self.get_endpoint(entry['endpoint_id'])
                 if not endpoint['enabled']:
                     # Skip disabled endpoints.
                     continue
@@ -62,7 +62,7 @@ class EndpointFilterCatalog(sql.Catalog):
             except exception.EndpointNotFound:
                 # remove bad reference from association
                 self.endpoint_filter_api.remove_endpoint_from_project(
-                    entry.endpoint_id, project_id)
+                    entry['endpoint_id'], project_id)
 
         # format catalog
         catalog = []
