@@ -14,27 +14,29 @@
 
 import six
 
-from keystone import assignment
 from keystone.catalog import controllers as catalog_controllers
 from keystone.common import controller
 from keystone.common import dependency
+from keystone.common import validation
+from keystone.contrib.endpoint_filter import schema
 from keystone import exception
 from keystone import notifications
+from keystone import resource
 
 
-@dependency.requires('assignment_api', 'catalog_api', 'endpoint_filter_api')
+@dependency.requires('catalog_api', 'endpoint_filter_api', 'resource_api')
 class _ControllerBase(controller.V3Controller):
     """Base behaviors for endpoint filter controllers."""
 
     def _get_endpoint_groups_for_project(self, project_id):
         # recover the project endpoint group memberships and for each
         # membership recover the endpoint group
-        self.assignment_api.get_project(project_id)
+        self.resource_api.get_project(project_id)
         try:
             refs = self.endpoint_filter_api.list_endpoint_groups_for_project(
                 project_id)
             endpoint_groups = [self.endpoint_filter_api.get_endpoint_group(
-                ref.endpoint_group_id) for ref in refs]
+                ref['endpoint_group_id']) for ref in refs]
             return endpoint_groups
         except exception.EndpointGroupNotFound:
             return []
@@ -85,7 +87,7 @@ class EndpointFilterV3Controller(_ControllerBase):
         # The relationship can still be established even with a disabled
         # project as there are no security implications.
         self.catalog_api.get_endpoint(endpoint_id)
-        self.assignment_api.get_project(project_id)
+        self.resource_api.get_project(project_id)
         self.endpoint_filter_api.add_endpoint_to_project(endpoint_id,
                                                          project_id)
 
@@ -93,19 +95,18 @@ class EndpointFilterV3Controller(_ControllerBase):
     def check_endpoint_in_project(self, context, project_id, endpoint_id):
         """Verifies endpoint is currently associated with given project."""
         self.catalog_api.get_endpoint(endpoint_id)
-        self.assignment_api.get_project(project_id)
+        self.resource_api.get_project(project_id)
         self.endpoint_filter_api.check_endpoint_in_project(endpoint_id,
                                                            project_id)
 
     @controller.protected()
     def list_endpoints_for_project(self, context, project_id):
         """List all endpoints currently associated with a given project."""
-        self.assignment_api.get_project(project_id)
+        self.resource_api.get_project(project_id)
         refs = self.endpoint_filter_api.list_endpoints_for_project(project_id)
-
-        filtered_endpoints = dict(
-            (ref.endpoint_id, self.catalog_api.get_endpoint(
-                ref.endpoint_id)) for ref in refs)
+        filtered_endpoints = {ref['endpoint_id']:
+                              self.catalog_api.get_endpoint(ref['endpoint_id'])
+                              for ref in refs}
 
         # need to recover endpoint_groups associated with project
         # then for each endpoint group return the endpoints.
@@ -134,10 +135,10 @@ class EndpointFilterV3Controller(_ControllerBase):
         self.catalog_api.get_endpoint(endpoint_id)
         refs = self.endpoint_filter_api.list_projects_for_endpoint(endpoint_id)
 
-        projects = [self.assignment_api.get_project(
-            ref.project_id) for ref in refs]
-        return assignment.controllers.ProjectV3.wrap_collection(context,
-                                                                projects)
+        projects = [self.resource_api.get_project(
+            ref['project_id']) for ref in refs]
+        return resource.controllers.ProjectV3.wrap_collection(context,
+                                                              projects)
 
 
 class EndpointGroupV3Controller(_ControllerBase):
@@ -149,7 +150,16 @@ class EndpointGroupV3Controller(_ControllerBase):
     def __init__(self):
         super(EndpointGroupV3Controller, self).__init__()
 
+    @classmethod
+    def base_url(cls, context, path=None):
+        """Construct a path and pass it to V3Controller.base_url method."""
+
+        path = '/OS-EP-FILTER/' + cls.collection_name
+        return super(EndpointGroupV3Controller, cls).base_url(context,
+                                                              path=path)
+
     @controller.protected()
+    @validation.validated(schema.endpoint_group_create, 'endpoint_group')
     def create_endpoint_group(self, context, endpoint_group):
         """Creates an Endpoint Group with the associated filters."""
         ref = self._assign_unique_id(self._normalize_dict(endpoint_group))
@@ -177,6 +187,7 @@ class EndpointGroupV3Controller(_ControllerBase):
             context, ref)
 
     @controller.protected()
+    @validation.validated(schema.endpoint_group_update, 'endpoint_group')
     def update_endpoint_group(self, context, endpoint_group_id,
                               endpoint_group):
         """Update fixed values and/or extend the filters."""
@@ -215,12 +226,12 @@ class EndpointGroupV3Controller(_ControllerBase):
                                    endpoint_group_id))
         projects = []
         for endpoint_group_ref in endpoint_group_refs:
-            project = self.assignment_api.get_project(
-                endpoint_group_ref.project_id)
+            project = self.resource_api.get_project(
+                endpoint_group_ref['project_id'])
             if project:
                 projects.append(project)
-        return assignment.controllers.ProjectV3.wrap_collection(context,
-                                                                projects)
+        return resource.controllers.ProjectV3.wrap_collection(context,
+                                                              projects)
 
     @controller.protected()
     def list_endpoints_associated_with_endpoint_group(self,
@@ -254,7 +265,7 @@ class ProjectEndpointGroupV3Controller(_ControllerBase):
     def get_endpoint_group_in_project(self, context, endpoint_group_id,
                                       project_id):
         """Retrieve the endpoint group associated with the id if exists."""
-        self.assignment_api.get_project(project_id)
+        self.resource_api.get_project(project_id)
         self.endpoint_filter_api.get_endpoint_group(endpoint_group_id)
         ref = self.endpoint_filter_api.get_endpoint_group_in_project(
             endpoint_group_id, project_id)
@@ -265,7 +276,7 @@ class ProjectEndpointGroupV3Controller(_ControllerBase):
     def add_endpoint_group_to_project(self, context, endpoint_group_id,
                                       project_id):
         """Creates an association between an endpoint group and project."""
-        self.assignment_api.get_project(project_id)
+        self.resource_api.get_project(project_id)
         self.endpoint_filter_api.get_endpoint_group(endpoint_group_id)
         self.endpoint_filter_api.add_endpoint_group_to_project(
             endpoint_group_id, project_id)
@@ -274,7 +285,7 @@ class ProjectEndpointGroupV3Controller(_ControllerBase):
     def remove_endpoint_group_from_project(self, context, endpoint_group_id,
                                            project_id):
         """Remove the endpoint group from associated project."""
-        self.assignment_api.get_project(project_id)
+        self.resource_api.get_project(project_id)
         self.endpoint_filter_api.get_endpoint_group(endpoint_group_id)
         self.endpoint_filter_api.remove_endpoint_group_from_project(
             endpoint_group_id, project_id)
