@@ -321,21 +321,24 @@ class Auth(auth_controllers.Auth):
         token_id = auth['identity']['token']['id']
         token_data = self.token_provider_api.validate_token(token_id)
         token_ref = token_model.KeystoneToken(token_id, token_data)
-        subject = token_ref.user_name
-        roles = token_ref.role_names
 
         if not token_ref.project_scoped:
             action = _('Use a project scoped token when attempting to create '
                        'a SAML assertion')
             raise exception.ForbiddenAction(action=action)
 
+        subject = token_ref.user_name
+        roles = token_ref.role_names
         project = token_ref.project_name
         # NOTE(rodrigods): the domain name is necessary in order to distinguish
-        # between projects with the same name in different domains.
-        domain = token_ref.project_domain_name
+        # between projects and users with the same name in different domains.
+        project_domain_name = token_ref.project_domain_name
+        subject_domain_name = token_ref.user_domain_name
+
         generator = keystone_idp.SAMLGenerator()
-        response = generator.samlize_token(issuer, sp_url, subject, roles,
-                                           project, domain)
+        response = generator.samlize_token(
+            issuer, sp_url, subject, subject_domain_name,
+            roles, project, project_domain_name)
         return (response, service_provider)
 
     def _build_response_headers(self, service_provider):
