@@ -17,17 +17,20 @@
 from __future__ import absolute_import
 
 import abc
+import string
+import uuid
 
 import oauthlib.common
 from oauthlib import oauth1
+from oslo_config import cfg
+from oslo_log import log
 import six
-import uuid
 
 from keystone.common import dependency
 from keystone.common import extension
 from keystone.common import manager
-from keystone import config
 from keystone import exception
+from keystone.i18n import _LE
 from keystone import notifications
 
 
@@ -39,6 +42,11 @@ AuthorizationEndpoint = oauth1.AuthorizationEndpoint
 SIG_HMAC = oauth1.SIGNATURE_HMAC
 RequestTokenEndpoint = oauth1.RequestTokenEndpoint
 oRequest = oauthlib.common.Request
+# The characters used to generate verifiers are limited to alphanumerical
+# values for ease of manual entry. Commonly confused characters are omitted.
+VERIFIER_CHARS = string.ascii_letters + string.digits
+CONFUSED_CHARS = 'jiIl1oO0'
+VERIFIER_CHARS = ''.join(c for c in VERIFIER_CHARS if c not in CONFUSED_CHARS)
 
 
 class Token(object):
@@ -51,7 +59,8 @@ class Token(object):
         self.verifier = verifier
 
 
-CONF = config.CONF
+CONF = cfg.CONF
+LOG = log.getLogger(__name__)
 
 
 def token_generator(*args, **kwargs):
@@ -123,11 +132,15 @@ def get_oauth_headers(headers):
         params = oauth1.rfc5849.utils.parse_authorization_header(auth_header)
         parameters.update(dict(params))
         return parameters
+    else:
+        msg = _LE('Cannot retrieve Authorization headers')
+        LOG.error(msg)
+        raise exception.OAuthHeadersMissingError()
 
 
 def extract_non_oauth_params(query_string):
     params = oauthlib.common.extract_params(query_string)
-    return dict([(k, v) for k, v in params if not k.startswith('oauth_')])
+    return {k: v for k, v in params if not k.startswith('oauth_')}
 
 
 @dependency.provider('oauth_api')
@@ -145,32 +158,41 @@ class Manager(manager.Manager):
     def __init__(self):
         super(Manager, self).__init__(CONF.oauth1.driver)
 
-    @notifications.created(_CONSUMER)
-    def create_consumer(self, consumer_ref):
-        return self.driver.create_consumer(consumer_ref)
+    def create_consumer(self, consumer_ref, initiator=None):
+        ret = self.driver.create_consumer(consumer_ref)
+        notifications.Audit.created(self._CONSUMER, ret['id'], initiator)
+        return ret
 
-    @notifications.updated(_CONSUMER)
-    def update_consumer(self, consumer_id, consumer_ref):
-        return self.driver.update_consumer(consumer_id, consumer_ref)
+    def update_consumer(self, consumer_id, consumer_ref, initiator=None):
+        ret = self.driver.update_consumer(consumer_id, consumer_ref)
+        notifications.Audit.updated(self._CONSUMER, consumer_id, initiator)
+        return ret
 
-    @notifications.deleted(_CONSUMER)
-    def delete_consumer(self, consumer_id):
-        return self.driver.delete_consumer(consumer_id)
+    def delete_consumer(self, consumer_id, initiator=None):
+        ret = self.driver.delete_consumer(consumer_id)
+        notifications.Audit.deleted(self._CONSUMER, consumer_id, initiator)
+        return ret
 
-    @notifications.created(_ACCESS_TOKEN)
-    def create_access_token(self, request_id, access_token_duration):
-        return self.driver.create_access_token(request_id,
-                                               access_token_duration)
+    def create_access_token(self, request_id, access_token_duration,
+                            initiator=None):
+        ret = self.driver.create_access_token(request_id,
+                                              access_token_duration)
+        notifications.Audit.created(self._ACCESS_TOKEN, ret['id'], initiator)
+        return ret
 
-    @notifications.deleted(_ACCESS_TOKEN, resource_id_arg_index=2)
-    def delete_access_token(self, user_id, access_token_id):
-        return self.driver.delete_access_token(user_id, access_token_id)
+    def delete_access_token(self, user_id, access_token_id, initiator=None):
+        ret = self.driver.delete_access_token(user_id, access_token_id)
+        notifications.Audit.deleted(self._ACCESS_TOKEN, access_token_id,
+                                    initiator)
+        return ret
 
-    @notifications.created(_REQUEST_TOKEN, resource_id_arg_index=2)
     def create_request_token(self, consumer_id, requested_project,
-                             request_token_duration):
-        return self.driver.create_request_token(
+                             request_token_duration, initiator=None):
+        ret = self.driver.create_request_token(
             consumer_id, requested_project, request_token_duration)
+        notifications.Audit.created(self._REQUEST_TOKEN, ret['id'],
+                                    initiator)
+        return ret
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -186,7 +208,7 @@ class Driver(object):
         :returns: consumer_ref
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def update_consumer(self, consumer_id, consumer_ref):
@@ -199,7 +221,7 @@ class Driver(object):
         :returns: consumer_ref
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def list_consumers(self):
@@ -208,7 +230,7 @@ class Driver(object):
         :returns: list of consumers
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def get_consumer(self, consumer_id):
@@ -220,7 +242,7 @@ class Driver(object):
         :returns: consumer_ref
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def get_consumer_with_secret(self, consumer_id):
@@ -235,7 +257,7 @@ class Driver(object):
         :returns: consumer_ref
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def delete_consumer(self, consumer_id):
@@ -246,7 +268,7 @@ class Driver(object):
         :returns: None.
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def list_access_tokens(self, user_id):
@@ -257,7 +279,7 @@ class Driver(object):
         :returns: list of access tokens the user has authorized
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def delete_access_token(self, user_id, access_token_id):
@@ -270,7 +292,7 @@ class Driver(object):
         :returns: None
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def create_request_token(self, consumer_id, requested_project,
@@ -286,7 +308,7 @@ class Driver(object):
         :returns: request_token_ref
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def get_request_token(self, request_token_id):
@@ -297,7 +319,7 @@ class Driver(object):
         :returns: request_token_ref
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def get_access_token(self, access_token_id):
@@ -308,7 +330,7 @@ class Driver(object):
         :returns: access_token_ref
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def authorize_request_token(self, request_id, user_id, role_ids):
@@ -323,7 +345,7 @@ class Driver(object):
         :returns: verifier
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def create_access_token(self, request_id, access_token_duration):
@@ -336,4 +358,4 @@ class Driver(object):
         :returns: access_token_ref
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
