@@ -12,15 +12,11 @@
 
 import uuid
 
-from keystone.common import config
 from keystone.common import sql
 from keystone.contrib import revoke
 from keystone.contrib.revoke import model
 
 
-CONF = config.CONF
-
-
 class RevocationEvent(sql.ModelBase, sql.ModelDictMixin):
     __tablename__ = 'revocation_event'
     attributes = model.REVOKE_KEYS
@@ -37,7 +33,9 @@ class RevocationEvent(sql.ModelBase, sql.ModelDictMixin):
     access_token_id = sql.Column(sql.String(64))
     issued_before = sql.Column(sql.DateTime(), nullable=False)
     expires_at = sql.Column(sql.DateTime())
-    revoked_at = sql.Column(sql.DateTime(), nullable=False)
+    revoked_at = sql.Column(sql.DateTime(), nullable=False, index=True)
+    audit_id = sql.Column(sql.String(32))
+    audit_chain_id = sql.Column(sql.String(32))
 
 
 class Revoke(revoke.Driver):
@@ -82,21 +80,15 @@ class Revoke(revoke.Driver):
 
         session.flush()
 
-    def get_events(self, last_fetch=None):
-        self._prune_expired_events()
+    def list_events(self, last_fetch=None):
         session = sql.get_session()
         query = session.query(RevocationEvent).order_by(
             RevocationEvent.revoked_at)
 
         if last_fetch:
-            query.filter(RevocationEvent.revoked_at >= last_fetch)
-            # While the query filter should handle this, it does not
-            # appear to be working. It might be a SQLite artifact.
-            events = [model.RevokeEvent(**e.to_dict())
-                      for e in query
-                      if e.revoked_at > last_fetch]
-        else:
-            events = [model.RevokeEvent(**e.to_dict()) for e in query]
+            query = query.filter(RevocationEvent.revoked_at > last_fetch)
+
+        events = [model.RevokeEvent(**e.to_dict()) for e in query]
 
         return events
 
@@ -109,3 +101,4 @@ class Revoke(revoke.Driver):
         session = sql.get_session()
         with session.begin():
             session.add(record)
+        self._prune_expired_events()
