@@ -10,13 +10,12 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo.config import cfg
+from oslo_config import cfg
 import webob
 
 from keystone.common import controller
 from keystone.common import dependency
 from keystone import exception
-from keystone.token.providers import pki
 
 CONF = cfg.CONF
 
@@ -25,10 +24,6 @@ CONF = cfg.CONF
 class SimpleCert(controller.V3Controller):
 
     def _get_certificate(self, name):
-        # If we aren't using the PKI Provider then we should return a 403
-        if not isinstance(self.token_provider_api.driver, pki.Provider):
-            raise exception.PKITokenExpected()
-
         try:
             with open(name, 'r') as f:
                 body = f.read()
