@@ -12,15 +12,17 @@
 
 """Unified in-memory token model."""
 
+from keystoneclient.common import cms
+from oslo_config import cfg
+from oslo_utils import timeutils
 import six
 
-from keystone.common import config
+from keystone.contrib import federation
 from keystone import exception
 from keystone.i18n import _
-from keystone.openstack.common import timeutils
 
 
-CONF = config.CONF
+CONF = cfg.CONF
 # supported token versions
 V2 = 'v2.0'
 V3 = 'v3.0'
@@ -52,11 +54,21 @@ class KeystoneToken(dict):
         else:
             raise exception.UnsupportedTokenVersionException()
         self.token_id = token_id
+        self.short_id = cms.cms_hash_token(token_id,
+                                           mode=CONF.token.hash_algorithm)
 
         if self.project_scoped and self.domain_scoped:
             raise exception.UnexpectedError(_('Found invalid token: scoped to '
                                               'both project and domain.'))
 
+    def __repr__(self):
+        desc = ('<%(type)s (audit_id=%(audit_id)s, '
+                'audit_chain_id=%(audit_chain_id)s) at %(loc)s>')
+        return desc % {'type': self.__class__.__name__,
+                       'audit_id': self.audit_id,
+                       'audit_chain_id': self.audit_chain_id,
+                       'loc': hex(id(self))}
+
     @property
     def expires(self):
         if self.version is V3:
@@ -73,6 +85,18 @@ class KeystoneToken(dict):
             issued_at = self['token']['issued_at']
         return _parse_and_normalize_time(issued_at)
 
+    @property
+    def audit_id(self):
+        if self.version is V3:
+            return self.get('audit_ids', [None])[0]
+        return self['token'].get('audit_ids', [None])[0]
+
+    @property
+    def audit_chain_id(self):
+        if self.version is V3:
+            return self.get('audit_ids', [None])[-1]
+        return self['token'].get('audit_ids', [None])[-1]
+
     @property
     def auth_token(self):
         return self.token_id
@@ -105,7 +129,7 @@ class KeystoneToken(dict):
             elif 'user' in self:
                 return CONF.identity.default_domain_id
         except KeyError:
-        # Do not raise KeyError, raise UnexpectedError
+            # Do not raise KeyError, raise UnexpectedError
             pass
         raise exception.UnexpectedError()
 
@@ -227,15 +251,26 @@ class KeystoneToken(dict):
             return self.get('trust', {}).get('trustor_user_id')
 
     @property
-    def oauth_access_token_id(self):
+    def trust_impersonation(self):
         if self.version is V3:
-            return self.get('OS-OAUTH1', {}).get('access_token_id')
+            return self.get('OS-TRUST:trust', {}).get('impersonation')
+        else:
+            return self.get('trust', {}).get('impersonation')
+
+    @property
+    def oauth_scoped(self):
+        return 'OS-OAUTH1' in self
+
+    @property
+    def oauth_access_token_id(self):
+        if self.version is V3 and self.oauth_scoped:
+            return self['OS-OAUTH1']['access_token_id']
         return None
 
     @property
     def oauth_consumer_id(self):
-        if self.version is V3:
-            return self.get('OS-OAUTH1', {}).get('consumer_id')
+        if self.version is V3 and self.oauth_scoped:
+            return self['OS-OAUTH1']['consumer_id']
         return None
 
     @property
@@ -257,3 +292,44 @@ class KeystoneToken(dict):
         if self.version is V3:
             return self.get('bind')
         return self.get('token', {}).get('bind')
+
+    @property
+    def is_federated_user(self):
+        try:
+            return self.version is V3 and federation.FEDERATION in self['user']
+        except KeyError:
+            raise exception.UnexpectedError()
+
+    @property
+    def federation_group_ids(self):
+        if self.is_federated_user:
+            if self.version is V3:
+                try:
+                    groups = self['user'][federation.FEDERATION].get(
+                        'groups', [])
+                    return [g['id'] for g in groups]
+                except KeyError:
+                    raise exception.UnexpectedError()
+        return []
+
+    @property
+    def federation_idp_id(self):
+        if self.version is not V3 or not self.is_federated_user:
+            return None
+        return self['user'][federation.FEDERATION]['identity_provider']['id']
+
+    @property
+    def federation_protocol_id(self):
+        if self.version is V3 and self.is_federated_user:
+            return self['user'][federation.FEDERATION]['protocol']['id']
+        return None
+
+    @property
+    def metadata(self):
+        return self.get('metadata', {})
+
+    @property
+    def methods(self):
+        if self.version is V3:
+            return self.get('methods', [])
+        return []
