@@ -16,9 +16,8 @@ import uuid
 
 from oslo_config import cfg
 from oslo_log import log
-from oslo_log import versionutils
 
-from keystone.common import clean
+from keystone import clean
 from keystone.common import driver_hints
 from keystone.common import ldap as common_ldap
 from keystone.common import models
@@ -32,11 +31,7 @@ CONF = cfg.CONF
 LOG = log.getLogger(__name__)
 
 
-class Resource(resource.ResourceDriverV8):
-    @versionutils.deprecated(
-        versionutils.deprecated.LIBERTY,
-        remove_in=+1,
-        what='ldap resource')
+class Resource(resource.Driver):
     def __init__(self):
         super(Resource, self).__init__()
         self.LDAP_URL = CONF.ldap.url
@@ -52,7 +47,7 @@ class Resource(resource.ResourceDriverV8):
         self.project = ProjectApi(CONF)
 
     def default_assignment_driver(self):
-        return 'ldap'
+        return 'keystone.assignment.backends.ldap.Assignment'
 
     def _set_default_parent_project(self, ref):
         """If the parent project ID has not been set, set it to None."""
@@ -65,14 +60,6 @@ class Resource(resource.ResourceDriverV8):
         else:
             raise ValueError(_('Expected dict or list: %s') % type(ref))
 
-    def _set_default_is_domain_project(self, ref):
-        if isinstance(ref, dict):
-            return dict(ref, is_domain=False)
-        elif isinstance(ref, list):
-            return [self._set_default_is_domain_project(x) for x in ref]
-        else:
-            raise ValueError(_('Expected dict or list: %s') % type(ref))
-
     def _validate_parent_project_is_none(self, ref):
         """If a parent_id different from None was given,
            raises InvalidProjectException.
@@ -82,15 +69,8 @@ class Resource(resource.ResourceDriverV8):
         if parent_id is not None:
             raise exception.InvalidParentProject(parent_id)
 
-    def _validate_is_domain_field_is_false(self, ref):
-        is_domain = ref.pop('is_domain', None)
-        if is_domain:
-            raise exception.ValidationError(_('LDAP does not support projects '
-                                              'with is_domain flag enabled'))
-
     def _set_default_attributes(self, project_ref):
         project_ref = self._set_default_domain(project_ref)
-        project_ref = self._set_default_is_domain_project(project_ref)
         return self._set_default_parent_project(project_ref)
 
     def get_project(self, tenant_id):
@@ -136,8 +116,8 @@ class Resource(resource.ResourceDriverV8):
 
     def create_project(self, tenant_id, tenant):
         self.project.check_allow_create()
+        tenant = self._validate_default_domain(tenant)
         self._validate_parent_project_is_none(tenant)
-        self._validate_is_domain_field_is_false(tenant)
         tenant['name'] = clean.project_name(tenant['name'])
         data = tenant.copy()
         if 'id' not in data or data['id'] is None:
@@ -150,7 +130,6 @@ class Resource(resource.ResourceDriverV8):
     def update_project(self, tenant_id, tenant):
         self.project.check_allow_update()
         tenant = self._validate_default_domain(tenant)
-        self._validate_is_domain_field_is_false(tenant)
         if 'name' in tenant:
             tenant['name'] = clean.project_name(tenant['name'])
         return self._set_default_attributes(
