@@ -14,26 +14,19 @@
 
 import uuid
 
-from keystone.common import provider_api
-import keystone.conf
-from keystone import exception
-
-PROVIDERS = provider_api.ProviderAPIs
-CONF = keystone.conf.CONF
+from oslo_config import cfg
 
 
-class FilterTests:
+CONF = cfg.CONF
+
+
+class FilterTests(object):
 
     # Provide support for checking if a batch of list items all
     # exist within a contiguous range in a total list
-    def _match_with_list(
-        self,
-        this_batch,
-        total_list,
-        batch_size=None,
-        list_start=None,
-        list_end=None,
-    ):
+    def _match_with_list(self, this_batch, total_list,
+                         batch_size=None,
+                         list_start=None, list_end=None):
         if batch_size is None:
             batch_size = len(this_batch)
         if list_start is None:
@@ -48,68 +41,37 @@ class FilterTests:
             self.assertTrue(found)
 
     def _create_entity(self, entity_type):
-        """Find the create_<entity_type> method.
-
-        Searches through the [identity_api, resource_api, assignment_api]
-        managers for a method called create_<entity_type> and returns the first
-        one.
-
-        """
-        f = getattr(PROVIDERS.identity_api, 'create_%s' % entity_type, None)
+        f = getattr(self.identity_api, 'create_%s' % entity_type, None)
         if f is None:
-            f = getattr(
-                PROVIDERS.resource_api, 'create_%s' % entity_type, None
-            )
-        if f is None:
-            f = getattr(PROVIDERS.assignment_api, 'create_%s' % entity_type)
+            f = getattr(self.assignment_api, 'create_%s' % entity_type)
         return f
 
     def _delete_entity(self, entity_type):
-        """Find the delete_<entity_type> method.
-
-        Searches through the [identity_api, resource_api, assignment_api]
-        managers for a method called delete_<entity_type> and returns the first
-        one.
-
-        """
-        f = getattr(PROVIDERS.identity_api, 'delete_%s' % entity_type, None)
+        f = getattr(self.identity_api, 'delete_%s' % entity_type, None)
         if f is None:
-            f = getattr(
-                PROVIDERS.resource_api, 'delete_%s' % entity_type, None
-            )
-        if f is None:
-            f = getattr(PROVIDERS.assignment_api, 'delete_%s' % entity_type)
+            f = getattr(self.assignment_api, 'delete_%s' % entity_type)
         return f
 
     def _list_entities(self, entity_type):
-        """Find the list_<entity_type> method.
-
-        Searches through the [identity_api, resource_api, assignment_api]
-        managers for a method called list_<entity_type> and returns the first
-        one.
-
-        """
-        f = getattr(PROVIDERS.identity_api, 'list_%ss' % entity_type, None)
+        f = getattr(self.identity_api, 'list_%ss' % entity_type, None)
         if f is None:
-            f = getattr(PROVIDERS.resource_api, 'list_%ss' % entity_type, None)
-        if f is None:
-            f = getattr(PROVIDERS.assignment_api, 'list_%ss' % entity_type)
+            f = getattr(self.assignment_api, 'list_%ss' % entity_type)
         return f
 
     def _create_one_entity(self, entity_type, domain_id, name):
-        new_entity = {'name': name, 'domain_id': domain_id}
+        new_entity = {'name': name,
+                      'domain_id': domain_id}
         if entity_type in ['user', 'group']:
             # The manager layer creates the ID for users and groups
             new_entity = self._create_entity(entity_type)(new_entity)
         else:
-            new_entity['id'] = uuid.uuid4().hex
+            new_entity['id'] = '0000' + uuid.uuid4().hex
             self._create_entity(entity_type)(new_entity['id'], new_entity)
         return new_entity
 
-    def _create_test_data(
-        self, entity_type, number, domain_id=None, name_dict=None
-    ):
-        """Create entity test data.
+    def _create_test_data(self, entity_type, number, domain_id=None,
+                          name_dict=None):
+        """Create entity test data
 
         :param entity_type: type of entity to create, e.g. 'user', group' etc.
         :param number: number of entities to create,
@@ -131,9 +93,4 @@ class FilterTests:
 
     def _delete_test_data(self, entity_type, entity_list):
         for entity in entity_list:
-            try:
-                self._delete_entity(entity_type)(entity['id'])
-            except exception.Forbidden:
-                # Note(knikolla): Some identity backends such as LDAP are
-                # read only
-                break
+            self._delete_entity(entity_type)(entity['id'])
