@@ -14,17 +14,19 @@
 import datetime
 import uuid
 
+from oslo_config import cfg
 from oslo_utils import timeutils
 import six
 
-from keystone.common import utils
 from keystone import exception
-from keystone.tests import unit
-from keystone.tests.unit.ksfixtures import database
-from keystone.tests.unit.token import test_backends as token_tests
+from keystone.tests import unit as tests
+from keystone.tests.unit import test_backend
 
 
-class KvsToken(unit.TestCase, token_tests.TokenTests):
+CONF = cfg.CONF
+
+
+class KvsToken(tests.TestCase, test_backend.TokenTests):
     def setUp(self):
         super(KvsToken, self).setUp()
         self.load_backends()
@@ -65,13 +67,13 @@ class KvsToken(unit.TestCase, token_tests.TokenTests):
         valid_token_ref = token_persistence.get_token(valid_token_id)
         expired_token_ref = token_persistence.get_token(expired_token_id)
         expected_user_token_list = [
-            (valid_token_id, utils.isotime(valid_token_ref['expires'],
-                                           subsecond=True)),
-            (expired_token_id, utils.isotime(expired_token_ref['expires'],
-                                             subsecond=True))]
+            (valid_token_id, timeutils.isotime(valid_token_ref['expires'],
+                                               subsecond=True)),
+            (expired_token_id, timeutils.isotime(expired_token_ref['expires'],
+                                                 subsecond=True))]
         self.assertEqual(expected_user_token_list, user_token_list)
         new_expired_data = (expired_token_id,
-                            utils.isotime(
+                            timeutils.isotime(
                                 (timeutils.utcnow() - expire_delta),
                                 subsecond=True))
         self._update_user_token_index_direct(user_key, expired_token_id,
@@ -80,10 +82,10 @@ class KvsToken(unit.TestCase, token_tests.TokenTests):
             user_id=user_id)
         valid_token_ref_2 = token_persistence.get_token(valid_token_id_2)
         expected_user_token_list = [
-            (valid_token_id, utils.isotime(valid_token_ref['expires'],
-                                           subsecond=True)),
-            (valid_token_id_2, utils.isotime(valid_token_ref_2['expires'],
-                                             subsecond=True))]
+            (valid_token_id, timeutils.isotime(valid_token_ref['expires'],
+                                               subsecond=True)),
+            (valid_token_id_2, timeutils.isotime(valid_token_ref_2['expires'],
+                                                 subsecond=True))]
         user_token_list = token_persistence.driver._store.get(user_key)
         self.assertEqual(expected_user_token_list, user_token_list)
 
@@ -92,22 +94,79 @@ class KvsToken(unit.TestCase, token_tests.TokenTests):
         new_token_id, data = self.create_token_sample_data(user_id=user_id)
         new_token_ref = token_persistence.get_token(new_token_id)
         expected_user_token_list = [
-            (valid_token_id, utils.isotime(valid_token_ref['expires'],
-                                           subsecond=True)),
-            (new_token_id, utils.isotime(new_token_ref['expires'],
-                                         subsecond=True))]
+            (valid_token_id, timeutils.isotime(valid_token_ref['expires'],
+                                               subsecond=True)),
+            (new_token_id, timeutils.isotime(new_token_ref['expires'],
+                                             subsecond=True))]
         user_token_list = token_persistence.driver._store.get(user_key)
         self.assertEqual(expected_user_token_list, user_token_list)
 
 
-class KvsTokenCacheInvalidation(unit.TestCase,
-                                token_tests.TokenCacheInvalidation):
+class KvsCatalog(tests.TestCase, test_backend.CatalogTests):
+    def setUp(self):
+        super(KvsCatalog, self).setUp()
+        self.load_backends()
+        self._load_fake_catalog()
+
+    def config_overrides(self):
+        super(KvsCatalog, self).config_overrides()
+        self.config_fixture.config(
+            group='catalog',
+            driver='keystone.catalog.backends.kvs.Catalog')
+
+    def _load_fake_catalog(self):
+        self.catalog_foobar = self.catalog_api.driver._create_catalog(
+            'foo', 'bar',
+            {'RegionFoo': {'service_bar': {'foo': 'bar'}}})
+
+    def test_get_catalog_404(self):
+        # FIXME(dolph): this test should be moved up to test_backend
+        # FIXME(dolph): exceptions should be UserNotFound and ProjectNotFound
+        self.assertRaises(exception.NotFound,
+                          self.catalog_api.get_catalog,
+                          uuid.uuid4().hex,
+                          'bar')
+
+        self.assertRaises(exception.NotFound,
+                          self.catalog_api.get_catalog,
+                          'foo',
+                          uuid.uuid4().hex)
+
+    def test_get_catalog(self):
+        catalog_ref = self.catalog_api.get_catalog('foo', 'bar')
+        self.assertDictEqual(catalog_ref, self.catalog_foobar)
+
+    def test_get_catalog_endpoint_disabled(self):
+        # This test doesn't apply to KVS because with the KVS backend the
+        # application creates the catalog (including the endpoints) for each
+        # user and project. Whether endpoints are enabled or disabled isn't
+        # a consideration.
+        f = super(KvsCatalog, self).test_get_catalog_endpoint_disabled
+        self.assertRaises(exception.NotFound, f)
+
+    def test_get_v3_catalog_endpoint_disabled(self):
+        # There's no need to have disabled endpoints in the kvs catalog. Those
+        # endpoints should just be removed from the store. This just tests
+        # what happens currently when the super impl is called.
+        f = super(KvsCatalog, self).test_get_v3_catalog_endpoint_disabled
+        self.assertRaises(exception.NotFound, f)
+
+    def test_list_regions_filtered_by_parent_region_id(self):
+        self.skipTest('KVS backend does not support hints')
+
+    def test_service_filtering(self):
+        self.skipTest("kvs backend doesn't support filtering")
+
+
+class KvsTokenCacheInvalidation(tests.TestCase,
+                                test_backend.TokenCacheInvalidation):
     def setUp(self):
         super(KvsTokenCacheInvalidation, self).setUp()
-        self.useFixture(database.Database(self.sql_driver_version_overrides))
         self.load_backends()
         self._create_test_data()
 
     def config_overrides(self):
         super(KvsTokenCacheInvalidation, self).config_overrides()
-        self.config_fixture.config(group='token', driver='kvs')
+        self.config_fixture.config(
+            group='token',
+            driver='keystone.token.persistence.backends.kvs.Token')
