@@ -23,7 +23,7 @@ from oslo_config import cfg
 
 from keystone.common import cache
 from keystone import exception
-from keystone.tests import unit
+from keystone.tests import unit as tests
 
 
 CONF = cfg.CONF
@@ -47,12 +47,10 @@ def _copy_value(value):
 # backend unless you are running tests or expecting odd/strange results.
 class CacheIsolatingProxy(proxy.ProxyBackend):
     """Proxy that forces a memory copy of stored values.
-
-    The default in-memory cache-region does not perform a copy on values it is
-    meant to cache.  Therefore if the value is modified after set or after get,
-    the cached value also is modified.  This proxy does a copy as the last
+    The default in-memory cache-region does not perform a copy on values it
+    is meant to cache.  Therefore if the value is modified after set or after
+    get, the cached value also is modified.  This proxy does a copy as the last
     thing before storing data.
-
     """
     def get(self, key):
         return _copy_value(self.proxied.get(key))
@@ -76,7 +74,7 @@ class TestProxyValue(object):
         self.cached = False
 
 
-class CacheRegionTest(unit.TestCase):
+class CacheRegionTest(tests.TestCase):
 
     def setUp(self):
         super(CacheRegionTest, self).setUp()
@@ -293,7 +291,7 @@ class CacheRegionTest(unit.TestCase):
                           "bogus")
 
 
-class CacheNoopBackendTest(unit.TestCase):
+class CacheNoopBackendTest(tests.TestCase):
 
     def setUp(self):
         super(CacheNoopBackendTest, self).setUp()
