@@ -17,6 +17,7 @@ import uuid
 
 from dogpile.cache import api
 from dogpile.cache import proxy
+from dogpile.cache import util
 import mock
 import six
 from testtools import matchers
@@ -25,9 +26,7 @@ from keystone.common.kvs.backends import inmemdb
 from keystone.common.kvs.backends import memcached
 from keystone.common.kvs import core
 from keystone import exception
-from keystone.tests import unit
-from keystone.token.persistence.backends import kvs as token_kvs_backend
-
+from keystone.tests import unit as tests
 
 NO_VALUE = api.NO_VALUE
 
@@ -86,12 +85,9 @@ class RegionProxy2Fixture(proxy.ProxyBackend):
 
 
 class TestMemcacheDriver(api.CacheBackend):
-    """A test dogpile.cache backend.
-
-    This test backend conforms to the mixin-mechanism for
+    """A test dogpile.cache backend that conforms to the mixin-mechanism for
     overriding set and set_multi methods on dogpile memcached drivers.
     """
-
     class test_client(object):
         # FIXME(morganfainberg): Convert this test client over to using mock
         # and/or mock.MagicMock as appropriate
@@ -150,7 +146,7 @@ class TestMemcacheDriver(api.CacheBackend):
         self.client.set_multi(mapping, **self.set_arguments)
 
 
-class KVSTest(unit.TestCase):
+class KVSTest(tests.TestCase):
     def setUp(self):
         super(KVSTest, self).setUp()
         self.key_foo = 'foo_' + uuid.uuid4().hex
@@ -206,10 +202,10 @@ class KVSTest(unit.TestCase):
         kvs = self._get_kvs_region()
         kvs.configure('openstack.kvs.Memory')
 
-        self.assertIs(kvs._region.key_mangler, core.sha1_mangle_key)
+        self.assertIs(kvs._region.key_mangler, util.sha1_mangle_key)
         # The backend should also have the keymangler set the same as the
         # region now.
-        self.assertIs(kvs._region.backend.key_mangler, core.sha1_mangle_key)
+        self.assertIs(kvs._region.backend.key_mangler, util.sha1_mangle_key)
 
     def test_kvs_key_mangler_configuration_backend(self):
         kvs = self._get_kvs_region()
@@ -220,7 +216,7 @@ class KVSTest(unit.TestCase):
     def test_kvs_key_mangler_configuration_forced_backend(self):
         kvs = self._get_kvs_region()
         kvs.configure('openstack.kvs.KVSBackendForcedKeyMangleFixture',
-                      key_mangler=core.sha1_mangle_key)
+                      key_mangler=util.sha1_mangle_key)
         expected = KVSBackendForcedKeyMangleFixture.key_mangler(self.key_foo)
         self.assertEqual(expected, kvs._region.key_mangler(self.key_foo))
 
@@ -239,7 +235,7 @@ class KVSTest(unit.TestCase):
 
         kvs = self._get_kvs_region()
         kvs.configure('openstack.kvs.Memory')
-        self.assertIs(kvs._region.backend.key_mangler, core.sha1_mangle_key)
+        self.assertIs(kvs._region.backend.key_mangler, util.sha1_mangle_key)
         kvs._set_key_mangler(test_key_mangler)
         self.assertIs(kvs._region.backend.key_mangler, test_key_mangler)
 
@@ -435,7 +431,7 @@ class KVSTest(unit.TestCase):
                       no_expiry_keys=no_expiry_keys)
         calculated_keys = set([kvs._region.key_mangler(key)
                                for key in no_expiry_keys])
-        self.assertIs(kvs._region.backend.key_mangler, core.sha1_mangle_key)
+        self.assertIs(kvs._region.backend.key_mangler, util.sha1_mangle_key)
         self.assertSetEqual(calculated_keys,
                             kvs._region.backend.no_expiry_hashed_keys)
         self.assertSetEqual(no_expiry_keys,
@@ -453,7 +449,7 @@ class KVSTest(unit.TestCase):
         kvs.configure('openstack.kvs.Memcached',
                       memcached_backend='TestDriver',
                       no_expiry_keys=no_expiry_keys)
-        self.assertIs(kvs._region.backend.key_mangler, core.sha1_mangle_key)
+        self.assertIs(kvs._region.backend.key_mangler, util.sha1_mangle_key)
         kvs._region.backend.key_mangler = None
         self.assertSetEqual(kvs._region.backend.raw_no_expiry_keys,
                             kvs._region.backend.no_expiry_hashed_keys)
@@ -491,21 +487,19 @@ class KVSTest(unit.TestCase):
                       memcached_expire_time=memcache_expire_time,
                       some_other_arg=uuid.uuid4().hex,
                       no_expiry_keys=[self.key_bar])
-        kvs_driver = kvs._region.backend.driver
-
         # Ensure the set_arguments are correct
         self.assertDictEqual(
-            expected_set_args,
-            kvs._region.backend._get_set_arguments_driver_attr())
+            kvs._region.backend._get_set_arguments_driver_attr(),
+            expected_set_args)
 
         # Set a key that would have an expiry and verify the correct result
         # occurred and that the correct set_arguments were passed.
         kvs.set(self.key_foo, self.value_foo)
         self.assertDictEqual(
-            expected_set_args,
-            kvs._region.backend.driver.client.set_arguments_passed)
-        observed_foo_keys = list(kvs_driver.client.keys_values.keys())
-        self.assertEqual(expected_foo_keys, observed_foo_keys)
+            kvs._region.backend.driver.client.set_arguments_passed,
+            expected_set_args)
+        self.assertEqual(expected_foo_keys,
+                         kvs._region.backend.driver.client.keys_values.keys())
         self.assertEqual(
             self.value_foo,
             kvs._region.backend.driver.client.keys_values[self.key_foo][0])
@@ -514,10 +508,10 @@ class KVSTest(unit.TestCase):
         # occurred and that the correct set_arguments were passed.
         kvs.set(self.key_bar, self.value_bar)
         self.assertDictEqual(
-            expected_no_expiry_args,
-            kvs._region.backend.driver.client.set_arguments_passed)
-        observed_bar_keys = list(kvs_driver.client.keys_values.keys())
-        self.assertEqual(expected_bar_keys, observed_bar_keys)
+            kvs._region.backend.driver.client.set_arguments_passed,
+            expected_no_expiry_args)
+        self.assertEqual(expected_bar_keys,
+                         kvs._region.backend.driver.client.keys_values.keys())
         self.assertEqual(
             self.value_bar,
             kvs._region.backend.driver.client.keys_values[self.key_bar][0])
@@ -526,10 +520,10 @@ class KVSTest(unit.TestCase):
         # result occurred and that the correct set_arguments were passed.
         kvs.set_multi(mapping_foo)
         self.assertDictEqual(
-            expected_set_args,
-            kvs._region.backend.driver.client.set_arguments_passed)
-        observed_foo_keys = list(kvs_driver.client.keys_values.keys())
-        self.assertEqual(expected_foo_keys, observed_foo_keys)
+            kvs._region.backend.driver.client.set_arguments_passed,
+            expected_set_args)
+        self.assertEqual(expected_foo_keys,
+                         kvs._region.backend.driver.client.keys_values.keys())
         self.assertEqual(
             self.value_foo,
             kvs._region.backend.driver.client.keys_values[self.key_foo][0])
@@ -538,10 +532,10 @@ class KVSTest(unit.TestCase):
         # result occurred and that the correct set_arguments were passed.
         kvs.set_multi(mapping_bar)
         self.assertDictEqual(
-            expected_no_expiry_args,
-            kvs._region.backend.driver.client.set_arguments_passed)
-        observed_bar_keys = list(kvs_driver.client.keys_values.keys())
-        self.assertEqual(expected_bar_keys, observed_bar_keys)
+            kvs._region.backend.driver.client.set_arguments_passed,
+            expected_no_expiry_args)
+        self.assertEqual(expected_bar_keys,
+                         kvs._region.backend.driver.client.keys_values.keys())
         self.assertEqual(
             self.value_bar,
             kvs._region.backend.driver.client.keys_values[self.key_bar][0])
@@ -572,7 +566,7 @@ class KVSTest(unit.TestCase):
                           key=test_key)
 
 
-class TestMemcachedBackend(unit.TestCase):
+class TestMemcachedBackend(tests.TestCase):
 
     @mock.patch('keystone.common.kvs.backends.memcached._', six.text_type)
     def test_invalid_backend_fails_initialization(self):
@@ -585,41 +579,3 @@ class TestMemcachedBackend(unit.TestCase):
         }
         self.assertThat(lambda: memcached.MemcachedBackend(options),
                         raises_valueerror)
-
-
-class TestCacheRegionInit(unit.TestCase):
-    """Illustrate the race condition on cache initialization.
-
-    This case doesn't actually expose the error, it just simulates unprotected
-    code behaviour, when race condition leads to re-configuration of shared
-    KVS backend object. What, in turn, results in an exception.
-    """
-
-    kvs_backend = token_kvs_backend.Token.kvs_backend
-    store_name = 'test-kvs'
-
-    def test_different_instances_initialization(self):
-        """Simulate race condition on token storage initialization."""
-        store = core.get_key_value_store(self.store_name)
-        self.assertFalse(store.is_configured)
-        other_store = core.get_key_value_store(self.store_name)
-        self.assertFalse(other_store.is_configured)
-
-        other_store.configure(backing_store=self.kvs_backend)
-        self.assertTrue(other_store.is_configured)
-        # This error shows that core.get_key_value_store() returns a shared
-        # object protected from re-configuration with an exception.
-        self.assertRaises(RuntimeError, store.configure,
-                          backing_store=self.kvs_backend)
-
-    def test_kvs_configure_called_twice(self):
-        """Check if configure() is called again."""
-        target = core.KeyValueStore
-        with mock.patch.object(target, 'configure') as configure_mock:
-            store = core.get_key_value_store(self.store_name)
-            other_store = core.get_key_value_store(self.store_name)
-
-            store.configure(backing_store=self.kvs_backend)
-            other_store.configure(backing_store=self.kvs_backend)
-
-            self.assertThat(configure_mock.mock_calls, matchers.HasLength(2))
