@@ -15,15 +15,14 @@
 import uuid
 
 import six
-from six.moves import range
 from testtools import matchers
 
 from keystone.common import controller
 from keystone import exception
-from keystone.tests import unit
+from keystone.tests import unit as tests
 
 
-class V3ControllerTestCase(unit.TestCase):
+class V3ControllerTestCase(tests.TestCase):
     """Tests for the V3Controller class."""
     def setUp(self):
         super(V3ControllerTestCase, self).setUp()
