@@ -13,7 +13,6 @@
 
 import uuid
 
-import six
 import testtools
 
 from keystone.assignment import schema as assignment_schema
@@ -25,10 +24,8 @@ from keystone.contrib.endpoint_filter import schema as endpoint_filter_schema
 from keystone.contrib.federation import schema as federation_schema
 from keystone.credential import schema as credential_schema
 from keystone import exception
-from keystone.identity import schema as identity_schema
 from keystone.policy import schema as policy_schema
 from keystone.resource import schema as resource_schema
-from keystone.tests import unit
 from keystone.trust import schema as trust_schema
 
 """Example model to validate create requests against. Assume that this is
@@ -67,12 +64,6 @@ entity_create = {
     'additionalProperties': True,
 }
 
-entity_create_optional_body = {
-    'type': 'object',
-    'properties': _entity_properties,
-    'additionalProperties': True,
-}
-
 entity_update = {
     'type': 'object',
     'properties': _entity_properties,
@@ -105,92 +96,7 @@ _VALID_FILTERS = [{'interface': 'admin'},
 _INVALID_FILTERS = ['some string', 1, 0, True, False]
 
 
-def expected_validation_failure(f):
-    def wrapper(self, *args, **kwargs):
-        args = (self,) + args
-        e = self.assertRaises(exception.ValidationError, f, *args, **kwargs)
-        self.assertIn('Expecting to find entity in request body',
-                      six.text_type(e))
-    return wrapper
-
-
-class ValidatedDecoratorTests(unit.BaseTestCase):
-
-    entity_schema = {
-        'type': 'object',
-        'properties': {
-            'name': parameter_types.name,
-        },
-        'required': ['name'],
-    }
-
-    valid_entity = {
-        'name': uuid.uuid4().hex,
-    }
-
-    @validation.validated(entity_create, 'entity')
-    def create_entity(self, entity):
-        """Used to test cases where validated param is the only param."""
-
-    @validation.validated(entity_create_optional_body, 'entity')
-    def create_entity_optional_body(self, entity):
-        """Used to test cases where there is an optional body."""
-
-    @validation.validated(entity_update, 'entity')
-    def update_entity(self, entity_id, entity):
-        """Used to test cases where validated param is not the only param."""
-
-    def test_calling_create_with_valid_entity_kwarg_succeeds(self):
-        self.create_entity(entity=self.valid_entity)
-
-    def test_calling_create_with_empty_entity_kwarg_succeeds(self):
-        """Test the case when client passing in an empty kwarg reference."""
-        self.create_entity_optional_body(entity={})
-
-    @expected_validation_failure
-    def test_calling_create_with_kwarg_as_None_fails(self):
-        self.create_entity(entity=None)
-
-    def test_calling_create_with_valid_entity_arg_succeeds(self):
-        self.create_entity(self.valid_entity)
-
-    def test_calling_create_with_empty_entity_arg_succeeds(self):
-        """Test the case when client passing in an empty entity reference."""
-        self.create_entity_optional_body({})
-
-    @expected_validation_failure
-    def test_calling_create_with_entity_arg_as_None_fails(self):
-        self.create_entity(None)
-
-    @expected_validation_failure
-    def test_calling_create_without_an_entity_fails(self):
-        self.create_entity()
-
-    def test_using_the_wrong_name_with_the_decorator_fails(self):
-        with testtools.ExpectedException(TypeError):
-            @validation.validated(self.entity_schema, 'entity_')
-            def function(entity):
-                pass
-
-    # NOTE(dstanek): below are the test cases for making sure the validation
-    # works when the validated param is not the only param. Since all of the
-    # actual validation cases are tested above these test are for a sanity
-    # check.
-
-    def test_calling_update_with_valid_entity_succeeds(self):
-        self.update_entity(uuid.uuid4().hex, self.valid_entity)
-
-    def test_calling_update_with_empty_entity_kwarg_succeeds(self):
-        """Test the case when client passing in an empty entity reference."""
-        global entity_update
-        original_entity_update = entity_update.copy()
-        # pop 'minProperties' from schema so that empty body is allowed.
-        entity_update.pop('minProperties')
-        self.update_entity(uuid.uuid4().hex, entity={})
-        entity_update = original_entity_update
-
-
-class EntityValidationTestCase(unit.BaseTestCase):
+class EntityValidationTestCase(testtools.TestCase):
 
     def setUp(self):
         super(EntityValidationTestCase, self).setUp()
@@ -393,7 +299,7 @@ class EntityValidationTestCase(unit.BaseTestCase):
                           request_to_validate)
 
 
-class ProjectValidationTestCase(unit.BaseTestCase):
+class ProjectValidationTestCase(testtools.TestCase):
     """Test for V3 Project API validation."""
 
     def setUp(self):
@@ -520,7 +426,7 @@ class ProjectValidationTestCase(unit.BaseTestCase):
                           request_to_validate)
 
 
-class DomainValidationTestCase(unit.BaseTestCase):
+class DomainValidationTestCase(testtools.TestCase):
     """Test for V3 Domain API validation."""
 
     def setUp(self):
@@ -618,7 +524,7 @@ class DomainValidationTestCase(unit.BaseTestCase):
                           request_to_validate)
 
 
-class RoleValidationTestCase(unit.BaseTestCase):
+class RoleValidationTestCase(testtools.TestCase):
     """Test for V3 Role API validation."""
 
     def setUp(self):
@@ -672,7 +578,7 @@ class RoleValidationTestCase(unit.BaseTestCase):
                           request_to_validate)
 
 
-class PolicyValidationTestCase(unit.BaseTestCase):
+class PolicyValidationTestCase(testtools.TestCase):
     """Test for V3 Policy API validation."""
 
     def setUp(self):
@@ -747,7 +653,7 @@ class PolicyValidationTestCase(unit.BaseTestCase):
                               request_to_validate)
 
 
-class CredentialValidationTestCase(unit.BaseTestCase):
+class CredentialValidationTestCase(testtools.TestCase):
     """Test for V3 Credential API validation."""
 
     def setUp(self):
@@ -864,7 +770,7 @@ class CredentialValidationTestCase(unit.BaseTestCase):
         self.update_credential_validator.validate(request_to_validate)
 
 
-class RegionValidationTestCase(unit.BaseTestCase):
+class RegionValidationTestCase(testtools.TestCase):
     """Test for V3 Region API validation."""
 
     def setUp(self):
@@ -898,24 +804,11 @@ class RegionValidationTestCase(unit.BaseTestCase):
                                'parent_region_id': uuid.uuid4().hex}
         self.create_region_validator.validate(request_to_validate)
 
-    def test_validate_region_create_fails_with_invalid_region_id(self):
-        """Exception raised when passing invalid `id` in request."""
-        request_to_validate = {'id': 1234,
-                               'description': 'US East Region'}
-        self.assertRaises(exception.SchemaValidationError,
-                          self.create_region_validator.validate,
-                          request_to_validate)
-
     def test_validate_region_create_succeeds_with_extra_parameters(self):
         """Validate create region request with extra values."""
         request_to_validate = {'other_attr': uuid.uuid4().hex}
         self.create_region_validator.validate(request_to_validate)
 
-    def test_validate_region_create_succeeds_with_no_parameters(self):
-        """Validate create region request with no parameters."""
-        request_to_validate = {}
-        self.create_region_validator.validate(request_to_validate)
-
     def test_validate_region_update_succeeds(self):
         """Test that we validate a region update request."""
         request_to_validate = {'id': 'us-west',
@@ -937,7 +830,7 @@ class RegionValidationTestCase(unit.BaseTestCase):
                           request_to_validate)
 
 
-class ServiceValidationTestCase(unit.BaseTestCase):
+class ServiceValidationTestCase(testtools.TestCase):
     """Test for V3 Service API validation."""
 
     def setUp(self):
@@ -1092,7 +985,7 @@ class ServiceValidationTestCase(unit.BaseTestCase):
                           request_to_validate)
 
 
-class EndpointValidationTestCase(unit.BaseTestCase):
+class EndpointValidationTestCase(testtools.TestCase):
     """Test for V3 Endpoint API validation."""
 
     def setUp(self):
@@ -1203,26 +1096,6 @@ class EndpointValidationTestCase(unit.BaseTestCase):
                           self.create_endpoint_validator.validate,
                           request_to_validate)
 
-    def test_validate_endpoint_create_fails_with_invalid_region_id(self):
-        """Exception raised when passing invalid `region(_id)` in request."""
-        request_to_validate = {'interface': 'admin',
-                               'region_id': 1234,
-                               'service_id': uuid.uuid4().hex,
-                               'url': 'https://service.example.com:5000/'}
-
-        self.assertRaises(exception.SchemaValidationError,
-                          self.create_endpoint_validator.validate,
-                          request_to_validate)
-
-        request_to_validate = {'interface': 'admin',
-                               'region': 1234,
-                               'service_id': uuid.uuid4().hex,
-                               'url': 'https://service.example.com:5000/'}
-
-        self.assertRaises(exception.SchemaValidationError,
-                          self.create_endpoint_validator.validate,
-                          request_to_validate)
-
     def test_validate_endpoint_update_fails_with_invalid_enabled(self):
         """Exception raised when `enabled` is boolean-like value."""
         for invalid_enabled in _INVALID_ENABLED_FORMATS:
@@ -1290,28 +1163,8 @@ class EndpointValidationTestCase(unit.BaseTestCase):
                               self.update_endpoint_validator.validate,
                               request_to_validate)
 
-    def test_validate_endpoint_update_fails_with_invalid_region_id(self):
-        """Exception raised when passing invalid `region(_id)` in request."""
-        request_to_validate = {'interface': 'admin',
-                               'region_id': 1234,
-                               'service_id': uuid.uuid4().hex,
-                               'url': 'https://service.example.com:5000/'}
 
-        self.assertRaises(exception.SchemaValidationError,
-                          self.update_endpoint_validator.validate,
-                          request_to_validate)
-
-        request_to_validate = {'interface': 'admin',
-                               'region': 1234,
-                               'service_id': uuid.uuid4().hex,
-                               'url': 'https://service.example.com:5000/'}
-
-        self.assertRaises(exception.SchemaValidationError,
-                          self.update_endpoint_validator.validate,
-                          request_to_validate)
-
-
-class EndpointGroupValidationTestCase(unit.BaseTestCase):
+class EndpointGroupValidationTestCase(testtools.TestCase):
     """Test for V3 Endpoint Group API validation."""
 
     def setUp(self):
@@ -1416,7 +1269,7 @@ class EndpointGroupValidationTestCase(unit.BaseTestCase):
                               request_to_validate)
 
 
-class TrustValidationTestCase(unit.BaseTestCase):
+class TrustValidationTestCase(testtools.TestCase):
     """Test for V3 Trust API validation."""
 
     _valid_roles = ['member', uuid.uuid4().hex, str(uuid.uuid4())]
@@ -1553,7 +1406,7 @@ class TrustValidationTestCase(unit.BaseTestCase):
         self.create_trust_validator.validate(request_to_validate)
 
 
-class ServiceProviderValidationTestCase(unit.BaseTestCase):
+class ServiceProviderValidationTestCase(testtools.TestCase):
     """Test for V3 Service Provider API validation."""
 
     def setUp(self):
@@ -1715,182 +1568,3 @@ class ServiceProviderValidationTestCase(unit.BaseTestCase):
         self.assertRaises(exception.SchemaValidationError,
                           self.update_sp_validator.validate,
                           request_to_validate)
-
-
-class UserValidationTestCase(unit.BaseTestCase):
-    """Test for V3 User API validation."""
-
-    def setUp(self):
-        super(UserValidationTestCase, self).setUp()
-
-        self.user_name = uuid.uuid4().hex
-
-        create = identity_schema.user_create
-        update = identity_schema.user_update
-        self.create_user_validator = validators.SchemaValidator(create)
-        self.update_user_validator = validators.SchemaValidator(update)
-
-    def test_validate_user_create_request_succeeds(self):
-        """Test that validating a user create request succeeds."""
-        request_to_validate = {'name': self.user_name}
-        self.create_user_validator.validate(request_to_validate)
-
-    def test_validate_user_create_with_all_valid_parameters_succeeds(self):
-        """Test that validating a user create request succeeds."""
-        request_to_validate = {'name': self.user_name,
-                               'default_project_id': uuid.uuid4().hex,
-                               'domain_id': uuid.uuid4().hex,
-                               'description': uuid.uuid4().hex,
-                               'enabled': True,
-                               'email': uuid.uuid4().hex,
-                               'password': uuid.uuid4().hex}
-        self.create_user_validator.validate(request_to_validate)
-
-    def test_validate_user_create_fails_without_name(self):
-        """Exception raised when validating a user without name."""
-        request_to_validate = {'email': uuid.uuid4().hex}
-        self.assertRaises(exception.SchemaValidationError,
-                          self.create_user_validator.validate,
-                          request_to_validate)
-
-    def test_validate_user_create_fails_with_name_of_zero_length(self):
-        """Exception raised when validating a username with length of zero."""
-        request_to_validate = {'name': ''}
-        self.assertRaises(exception.SchemaValidationError,
-                          self.create_user_validator.validate,
-                          request_to_validate)
-
-    def test_validate_user_create_fails_with_name_of_wrong_type(self):
-        """Exception raised when validating a username of wrong type."""
-        request_to_validate = {'name': True}
-        self.assertRaises(exception.SchemaValidationError,
-                          self.create_user_validator.validate,
-                          request_to_validate)
-
-    def test_validate_user_create_succeeds_with_valid_enabled_formats(self):
-        """Validate acceptable enabled formats in create user requests."""
-        for enabled in _VALID_ENABLED_FORMATS:
-            request_to_validate = {'name': self.user_name,
-                                   'enabled': enabled}
-            self.create_user_validator.validate(request_to_validate)
-
-    def test_validate_user_create_fails_with_invalid_enabled_formats(self):
-        """Exception raised when enabled is not an acceptable format."""
-        for invalid_enabled in _INVALID_ENABLED_FORMATS:
-            request_to_validate = {'name': self.user_name,
-                                   'enabled': invalid_enabled}
-            self.assertRaises(exception.SchemaValidationError,
-                              self.create_user_validator.validate,
-                              request_to_validate)
-
-    def test_validate_user_create_succeeds_with_extra_attributes(self):
-        """Validate extra parameters on user create requests."""
-        request_to_validate = {'name': self.user_name,
-                               'other_attr': uuid.uuid4().hex}
-        self.create_user_validator.validate(request_to_validate)
-
-    def test_validate_user_create_succeeds_with_password_of_zero_length(self):
-        """Validate empty password on user create requests."""
-        request_to_validate = {'name': self.user_name,
-                               'password': ''}
-        self.create_user_validator.validate(request_to_validate)
-
-    def test_validate_user_create_succeeds_with_null_password(self):
-        """Validate that password is nullable on create user."""
-        request_to_validate = {'name': self.user_name,
-                               'password': None}
-        self.create_user_validator.validate(request_to_validate)
-
-    def test_validate_user_create_fails_with_invalid_password_type(self):
-        """Exception raised when user password is of the wrong type."""
-        request_to_validate = {'name': self.user_name,
-                               'password': True}
-        self.assertRaises(exception.SchemaValidationError,
-                          self.create_user_validator.validate,
-                          request_to_validate)
-
-    def test_validate_user_create_succeeds_with_null_description(self):
-        """Validate that description can be nullable on create user."""
-        request_to_validate = {'name': self.user_name,
-                               'description': None}
-        self.create_user_validator.validate(request_to_validate)
-
-    def test_validate_user_update_succeeds(self):
-        """Validate an update user request."""
-        request_to_validate = {'email': uuid.uuid4().hex}
-        self.update_user_validator.validate(request_to_validate)
-
-    def test_validate_user_update_fails_with_no_parameters(self):
-        """Exception raised when updating nothing."""
-        request_to_validate = {}
-        self.assertRaises(exception.SchemaValidationError,
-                          self.update_user_validator.validate,
-                          request_to_validate)
-
-    def test_validate_user_update_succeeds_with_extra_parameters(self):
-        """Validate user update requests with extra parameters."""
-        request_to_validate = {'other_attr': uuid.uuid4().hex}
-        self.update_user_validator.validate(request_to_validate)
-
-
-class GroupValidationTestCase(unit.BaseTestCase):
-    """Test for V3 Group API validation."""
-
-    def setUp(self):
-        super(GroupValidationTestCase, self).setUp()
-
-        self.group_name = uuid.uuid4().hex
-
-        create = identity_schema.group_create
-        update = identity_schema.group_update
-        self.create_group_validator = validators.SchemaValidator(create)
-        self.update_group_validator = validators.SchemaValidator(update)
-
-    def test_validate_group_create_succeeds(self):
-        """Validate create group requests."""
-        request_to_validate = {'name': self.group_name}
-        self.create_group_validator.validate(request_to_validate)
-
-    def test_validate_group_create_succeeds_with_all_parameters(self):
-        """Validate create group requests with all parameters."""
-        request_to_validate = {'name': self.group_name,
-                               'description': uuid.uuid4().hex,
-                               'domain_id': uuid.uuid4().hex}
-        self.create_group_validator.validate(request_to_validate)
-
-    def test_validate_group_create_fails_without_group_name(self):
-        """Exception raised when group name is not provided in request."""
-        request_to_validate = {'description': uuid.uuid4().hex}
-        self.assertRaises(exception.SchemaValidationError,
-                          self.create_group_validator.validate,
-                          request_to_validate)
-
-    def test_validate_group_create_fails_when_group_name_is_too_short(self):
-        """Exception raised when group name is equal to zero."""
-        request_to_validate = {'name': ''}
-        self.assertRaises(exception.SchemaValidationError,
-                          self.create_group_validator.validate,
-                          request_to_validate)
-
-    def test_validate_group_create_succeeds_with_extra_parameters(self):
-        """Validate extra attributes on group create requests."""
-        request_to_validate = {'name': self.group_name,
-                               'other_attr': uuid.uuid4().hex}
-        self.create_group_validator.validate(request_to_validate)
-
-    def test_validate_group_update_succeeds(self):
-        """Validate group update requests."""
-        request_to_validate = {'description': uuid.uuid4().hex}
-        self.update_group_validator.validate(request_to_validate)
-
-    def test_validate_group_update_fails_with_no_parameters(self):
-        """Exception raised when no parameters passed in on update."""
-        request_to_validate = {}
-        self.assertRaises(exception.SchemaValidationError,
-                          self.update_group_validator.validate,
-                          request_to_validate)
-
-    def test_validate_group_update_succeeds_with_extra_parameters(self):
-        """Validate group update requests with extra parameters."""
-        request_to_validate = {'other_attr': uuid.uuid4().hex}
-        self.update_group_validator.validate(request_to_validate)
