@@ -10,11 +10,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from keystone.tests import unit
+from keystone.tests import unit as tests
 from keystone.token.providers import pki
 
 
-class TestPkiTokenProvider(unit.TestCase):
+class TestPkiTokenProvider(tests.TestCase):
     def setUp(self):
         super(TestPkiTokenProvider, self).setUp()
         self.provider = pki.Provider()
@@ -23,4 +23,4 @@ class TestPkiTokenProvider(unit.TestCase):
         self.assertTrue(self.provider._supports_bind_authentication)
 
     def test_need_persistence_return_true(self):
-        self.assertIs(True, self.provider.needs_persistence())
+        self.assertTrue(self.provider.needs_persistence)
