@@ -13,23 +13,25 @@
 #    under the License.
 
 import datetime
-import json
+import sys
 
 from keystoneclient.common import cms
+from oslo_config import cfg
+from oslo_log import log
+from oslo_serialization import jsonutils
+from oslo_utils import timeutils
 import six
 
 from keystone.common import controller
 from keystone.common import dependency
 from keystone.common import wsgi
-from keystone import config
 from keystone import exception
-from keystone.openstack.common.gettextutils import _
-from keystone.openstack.common import log
-from keystone.openstack.common import timeutils
-from keystone.token import core
+from keystone.i18n import _
+from keystone.models import token_model
+from keystone.token import provider
 
 
-CONF = config.CONF
+CONF = cfg.CONF
 LOG = log.getLogger(__name__)
 
 
@@ -39,7 +41,8 @@ class ExternalAuthNotApplicable(Exception):
 
 
 @dependency.requires('assignment_api', 'catalog_api', 'identity_api',
-                     'token_api', 'token_provider_api', 'trust_api')
+                     'resource_api', 'role_api', 'token_provider_api',
+                     'trust_api')
 class Auth(controller.V2Controller):
 
     @controller.v2_deprecated
@@ -97,8 +100,17 @@ class Auth(controller.V2Controller):
                 auth_info = self._authenticate_local(
                     context, auth)
 
-        user_ref, tenant_ref, metadata_ref, expiry, bind = auth_info
-        core.validate_auth_info(self, user_ref, tenant_ref)
+        user_ref, tenant_ref, metadata_ref, expiry, bind, audit_id = auth_info
+        # Validate that the auth info is valid and nothing is disabled
+        try:
+            self.identity_api.assert_user_enabled(
+                user_id=user_ref['id'], user=user_ref)
+            if tenant_ref:
+                self.resource_api.assert_project_enabled(
+                    project_id=tenant_ref['id'], project=tenant_ref)
+        except AssertionError as e:
+            six.reraise(exception.Unauthorized, exception.Unauthorized(e),
+                        sys.exc_info()[2])
         # NOTE(morganfainberg): Make sure the data is in correct form since it
         # might be consumed external to Keystone and this is a v2.0 controller.
         # The user_ref is encoded into the auth_token_data which is returned as
@@ -106,15 +118,17 @@ class Auth(controller.V2Controller):
         # format.
         user_ref = self.v3_to_v2_user(user_ref)
         if tenant_ref:
-            tenant_ref = self.filter_domain_id(tenant_ref)
+            tenant_ref = self.v3_to_v2_project(tenant_ref)
+
         auth_token_data = self._get_auth_token_data(user_ref,
                                                     tenant_ref,
                                                     metadata_ref,
-                                                    expiry)
+                                                    expiry,
+                                                    audit_id)
 
         if tenant_ref:
             catalog_ref = self.catalog_api.get_catalog(
-                user_ref['id'], tenant_ref['id'], metadata_ref)
+                user_ref['id'], tenant_ref['id'])
         else:
             catalog_ref = {}
 
@@ -124,13 +138,28 @@ class Auth(controller.V2Controller):
 
         roles_ref = []
         for role_id in metadata_ref.get('roles', []):
-            role_ref = self.assignment_api.get_role(role_id)
+            role_ref = self.role_api.get_role(role_id)
             roles_ref.append(dict(name=role_ref['name']))
 
         (token_id, token_data) = self.token_provider_api.issue_v2_token(
             auth_token_data, roles_ref=roles_ref, catalog_ref=catalog_ref)
+
+        # NOTE(wanghong): We consume a trust use only when we are using trusts
+        # and have successfully issued a token.
+        if CONF.trust.enabled and 'trust_id' in auth:
+            self.trust_api.consume_use(auth['trust_id'])
+
         return token_data
 
+    def _restrict_scope(self, token_model_ref):
+        # A trust token cannot be used to get another token
+        if token_model_ref.trust_scoped:
+            raise exception.Forbidden()
+        if not CONF.token.allow_rescope_scoped_token:
+            # Do not allow conversion from scoped tokens.
+            if token_model_ref.project_scoped or token_model_ref.domain_scoped:
+                raise exception.Forbidden(action=_("rescope a scoped token"))
+
     def _authenticate_token(self, context, auth):
         """Try to authenticate using an already existing token.
 
@@ -150,20 +179,16 @@ class Auth(controller.V2Controller):
                                                 size=CONF.max_token_size)
 
         try:
-            old_token_ref = self.token_api.get_token(old_token)
+            token_model_ref = token_model.KeystoneToken(
+                token_id=old_token,
+                token_data=self.token_provider_api.validate_token(old_token))
         except exception.NotFound as e:
             raise exception.Unauthorized(e)
 
-        wsgi.validate_token_bind(context, old_token_ref)
+        wsgi.validate_token_bind(context, token_model_ref)
 
-        #A trust token cannot be used to get another token
-        if 'trust' in old_token_ref:
-            raise exception.Forbidden()
-        if 'trust_id' in old_token_ref['metadata']:
-            raise exception.Forbidden()
-
-        user_ref = old_token_ref['user']
-        user_id = user_ref['id']
+        self._restrict_scope(token_model_ref)
+        user_id = token_model_ref.user_id
         tenant_id = self._get_project_id_from_auth(auth)
 
         if not CONF.trust.enabled and 'trust_id' in auth:
@@ -180,17 +205,16 @@ class Auth(controller.V2Controller):
             if ('expires' in trust_ref) and (trust_ref['expires']):
                 expiry = trust_ref['expires']
                 if expiry < timeutils.parse_isotime(timeutils.isotime()):
-                    raise exception.Forbidden()()
+                    raise exception.Forbidden()
             user_id = trust_ref['trustor_user_id']
             trustor_user_ref = self.identity_api.get_user(
                 trust_ref['trustor_user_id'])
             if not trustor_user_ref['enabled']:
-                raise exception.Forbidden()()
+                raise exception.Forbidden()
             trustee_user_ref = self.identity_api.get_user(
                 trust_ref['trustee_user_id'])
             if not trustee_user_ref['enabled']:
-                raise exception.Forbidden()()
-            self.trust_api.consume_use(auth['trust_id'])
+                raise exception.Forbidden()
 
             if trust_ref['impersonation'] is True:
                 current_user_ref = trustor_user_ref
@@ -204,13 +228,13 @@ class Auth(controller.V2Controller):
         tenant_ref, metadata_ref['roles'] = self._get_project_roles_and_ref(
             user_id, tenant_id)
 
-        expiry = old_token_ref['expires']
+        expiry = token_model_ref.expires
         if CONF.trust.enabled and 'trust_id' in auth:
             trust_id = auth['trust_id']
             trust_roles = []
             for role in trust_ref['roles']:
                 if 'roles' not in metadata_ref:
-                    raise exception.Forbidden()()
+                    raise exception.Forbidden()
                 if role['id'] in metadata_ref['roles']:
                     trust_roles.append(role['id'])
                 else:
@@ -223,9 +247,11 @@ class Auth(controller.V2Controller):
             metadata_ref['trustee_user_id'] = trust_ref['trustee_user_id']
             metadata_ref['trust_id'] = trust_id
 
-        bind = old_token_ref.get('bind')
+        bind = token_model_ref.bind
+        audit_id = token_model_ref.audit_chain_id
 
-        return (current_user_ref, tenant_ref, metadata_ref, expiry, bind)
+        return (current_user_ref, tenant_ref, metadata_ref, expiry, bind,
+                audit_id)
 
     def _authenticate_local(self, context, auth):
         """Try to authenticate against the identity backend.
@@ -245,8 +271,8 @@ class Auth(controller.V2Controller):
             raise exception.ValidationSizeError(
                 attribute='password', size=CONF.identity.max_password_length)
 
-        if ("userId" not in auth['passwordCredentials'] and
-                "username" not in auth['passwordCredentials']):
+        if (not auth['passwordCredentials'].get("userId") and
+                not auth['passwordCredentials'].get("username")):
             raise exception.ValidationError(
                 attribute='username or userId',
                 target='passwordCredentials')
@@ -257,11 +283,11 @@ class Auth(controller.V2Controller):
                                                 size=CONF.max_param_size)
 
         username = auth['passwordCredentials'].get('username', '')
-        if len(username) > CONF.max_param_size:
-            raise exception.ValidationSizeError(attribute='username',
-                                                size=CONF.max_param_size)
 
         if username:
+            if len(username) > CONF.max_param_size:
+                raise exception.ValidationSizeError(attribute='username',
+                                                    size=CONF.max_param_size)
             try:
                 user_ref = self.identity_api.get_user_by_name(
                     username, CONF.identity.default_domain_id)
@@ -282,23 +308,21 @@ class Auth(controller.V2Controller):
         tenant_ref, metadata_ref['roles'] = self._get_project_roles_and_ref(
             user_id, tenant_id)
 
-        expiry = core.default_expire_time()
-        return (user_ref, tenant_ref, metadata_ref, expiry, None)
+        expiry = provider.default_expire_time()
+        bind = None
+        audit_id = None
+        return (user_ref, tenant_ref, metadata_ref, expiry, bind, audit_id)
 
     def _authenticate_external(self, context, auth):
         """Try to authenticate an external user via REMOTE_USER variable.
 
         Returns auth_token_data, (user_ref, tenant_ref, metadata_ref)
         """
-        if 'REMOTE_USER' not in context.get('environment', {}):
+        environment = context.get('environment', {})
+        if not environment.get('REMOTE_USER'):
             raise ExternalAuthNotApplicable()
 
-        #NOTE(jamielennox): xml and json differ and get confused about what
-        # empty auth should look like so just reset it.
-        if not auth:
-            auth = {}
-
-        username = context['environment']['REMOTE_USER']
+        username = environment['REMOTE_USER']
         try:
             user_ref = self.identity_api.get_user_by_name(
                 username, CONF.identity.default_domain_id)
@@ -311,20 +335,21 @@ class Auth(controller.V2Controller):
         tenant_ref, metadata_ref['roles'] = self._get_project_roles_and_ref(
             user_id, tenant_id)
 
-        expiry = core.default_expire_time()
+        expiry = provider.default_expire_time()
         bind = None
         if ('kerberos' in CONF.token.bind and
-                context['environment'].
-                get('AUTH_TYPE', '').lower() == 'negotiate'):
+                environment.get('AUTH_TYPE', '').lower() == 'negotiate'):
             bind = {'kerberos': username}
+        audit_id = None
 
-        return (user_ref, tenant_ref, metadata_ref, expiry, bind)
+        return (user_ref, tenant_ref, metadata_ref, expiry, bind, audit_id)
 
-    def _get_auth_token_data(self, user, tenant, metadata, expiry):
+    def _get_auth_token_data(self, user, tenant, metadata, expiry, audit_id):
         return dict(user=user,
                     tenant=tenant,
                     metadata=metadata,
-                    expires=expiry)
+                    expires=expiry,
+                    parent_audit_id=audit_id)
 
     def _get_project_id_from_auth(self, auth):
         """Extract tenant information from auth dict.
@@ -343,7 +368,7 @@ class Auth(controller.V2Controller):
 
         if tenant_name:
             try:
-                tenant_ref = self.assignment_api.get_project_by_name(
+                tenant_ref = self.resource_api.get_project_by_name(
                     tenant_name, CONF.identity.default_domain_id)
                 tenant_id = tenant_ref['id']
             except exception.ProjectNotFound as e:
@@ -357,7 +382,7 @@ class Auth(controller.V2Controller):
         role_list = []
         if tenant_id:
             try:
-                tenant_ref = self.assignment_api.get_project(tenant_id)
+                tenant_ref = self.resource_api.get_project(tenant_id)
                 role_list = self.assignment_api.get_roles_for_user_and_project(
                     user_id, tenant_id)
             except exception.ProjectNotFound:
@@ -377,15 +402,17 @@ class Auth(controller.V2Controller):
         Optionally, limited to a token owned by a specific tenant.
 
         """
-        data = self.token_api.get_token(token_id)
+        token_ref = token_model.KeystoneToken(
+            token_id=token_id,
+            token_data=self.token_provider_api.validate_token(token_id))
         if belongs_to:
-            if data.get('tenant') is None:
+            if not token_ref.project_scoped:
                 raise exception.Unauthorized(
                     _('Token does not belong to specified tenant.'))
-            if data['tenant'].get('id') != belongs_to:
+            if token_ref.project_id != belongs_to:
                 raise exception.Unauthorized(
                     _('Token does not belong to specified tenant.'))
-        return data
+        return token_ref
 
     @controller.v2_deprecated
     @controller.protected()
@@ -400,7 +427,6 @@ class Auth(controller.V2Controller):
         the content body.
 
         """
-        # TODO(ayoung) validate against revocation API
         belongs_to = context['query_string'].get('belongsTo')
         return self.token_provider_api.validate_v2_token(token_id, belongs_to)
 
@@ -430,14 +456,14 @@ class Auth(controller.V2Controller):
     def revocation_list(self, context, auth=None):
         if not CONF.token.revoke_by_id:
             raise exception.Gone()
-        tokens = self.token_api.list_revoked_tokens()
+        tokens = self.token_provider_api.list_revoked_tokens()
 
         for t in tokens:
             expires = t['expires']
             if expires and isinstance(expires, datetime.datetime):
-                    t['expires'] = timeutils.isotime(expires)
+                t['expires'] = timeutils.isotime(expires)
         data = {'revoked': tokens}
-        json_data = json.dumps(data)
+        json_data = jsonutils.dumps(data)
         signed_text = cms.cms_sign_text(json_data,
                                         CONF.signing.certfile,
                                         CONF.signing.keyfile)
@@ -452,11 +478,10 @@ class Auth(controller.V2Controller):
         token_ref = self._get_token_ref(token_id)
 
         catalog_ref = None
-        if token_ref.get('tenant'):
+        if token_ref.project_id:
             catalog_ref = self.catalog_api.get_catalog(
-                token_ref['user']['id'],
-                token_ref['tenant']['id'],
-                token_ref['metadata'])
+                token_ref.user_id,
+                token_ref.project_id)
 
         return Auth.format_endpoint_list(catalog_ref)
 
