@@ -16,19 +16,19 @@
 from __future__ import absolute_import
 import copy
 
-from oslo.utils import timeutils
+from oslo_config import cfg
+from oslo_log import log
+from oslo_utils import timeutils
 import six
 
 from keystone.common import kvs
-from keystone import config
 from keystone import exception
-from keystone.i18n import _
-from keystone.openstack.common import log
+from keystone.i18n import _, _LE, _LW
 from keystone import token
 from keystone.token import provider
 
 
-CONF = config.CONF
+CONF = cfg.CONF
 LOG = log.getLogger(__name__)
 
 
@@ -54,11 +54,12 @@ class Token(token.persistence.Driver):
         if self.__class__ == Token:
             # NOTE(morganfainberg): Only warn if the base KVS implementation
             # is instantiated.
-            LOG.warn(_('It is recommended to only use the base '
-                       'key-value-store implementation for the token driver '
-                       'for testing purposes.  '
-                       'Please use keystone.token.backends.memcache.Token '
-                       'or keystone.token.backends.sql.Token instead.'))
+            LOG.warn(_LW('It is recommended to only use the base '
+                         'key-value-store implementation for the token driver '
+                         'for testing purposes. Please use '
+                         'keystone.token.persistence.backends.memcache.Token '
+                         'or keystone.token.persistence.backends.sql.Token '
+                         'instead.'))
 
     def _prefix_token_id(self, token_id):
         return 'token-%s' % token_id.encode('utf-8')
@@ -202,14 +203,23 @@ class Token(token.persistence.Driver):
         expires = timeutils.normalize_time(expires)
 
         if expires < current_time:
-            LOG.warning(_('Token `%s` is expired, not adding to the '
-                          'revocation list.'), data['id'])
+            LOG.warning(_LW('Token `%s` is expired, not adding to the '
+                            'revocation list.'), data['id'])
             return
 
         revoked_token_data['expires'] = timeutils.isotime(expires,
                                                           subsecond=True)
         revoked_token_data['id'] = data['id']
 
+        token_data = data['token_data']
+        if 'access' in token_data:
+            # It's a v2 token.
+            audit_ids = token_data['access']['token']['audit_ids']
+        else:
+            # It's a v3 token.
+            audit_ids = token_data['token']['audit_ids']
+        revoked_token_data['audit_id'] = audit_ids[0]
+
         token_list = self._get_key_or_default(self.revocation_key, default=[])
         if not isinstance(token_list, list):
             # NOTE(morganfainberg): In the case that the revocation list is not
@@ -222,10 +232,10 @@ class Token(token.persistence.Driver):
             # be recoverable. Keystone cannot control external applications
             # from changing a key in some backends, however, it is possible to
             # gracefully handle and notify of this event.
-            LOG.error(_('Reinitializing revocation list due to error '
-                        'in loading revocation list from backend.  '
-                        'Expected `list` type got `%(type)s`. Old '
-                        'revocation list data: %(list)r'),
+            LOG.error(_LE('Reinitializing revocation list due to error '
+                          'in loading revocation list from backend.  '
+                          'Expected `list` type got `%(type)s`. Old '
+                          'revocation list data: %(list)r'),
                       {'type': type(token_list), 'list': token_list})
             token_list = []
 
@@ -236,8 +246,8 @@ class Token(token.persistence.Driver):
                 expires_at = timeutils.normalize_time(
                     timeutils.parse_isotime(token_data['expires']))
             except ValueError:
-                LOG.warning(_('Removing `%s` from revocation list due to '
-                              'invalid expires data in revocation list.'),
+                LOG.warning(_LW('Removing `%s` from revocation list due to '
+                                'invalid expires data in revocation list.'),
                             token_data.get('id', 'INVALID_TOKEN_DATA'))
                 continue
             if expires_at > current_time:
